// This work is licensed under the Attribution-ShareAlike 4.0 International.
//
//    Persistence of Vision Ray Tracer Include File
//
//    File           : farger.inc
//    Version        : 3.0
//    Created by     : Sven-Erik Andersen
//    Contact        : sven.erik.andersen@gmail.com
//    Created date   : 2014-06-22
//    Last updated   : 2019-10-26
//    Description    : Farger means colors in Norwegian.
//                     This is an extended include file with, at the moment, 1701 named color definitions.
//                     It is mostly based on the Wikipedia list of colors that you can find at:
//                     http://en.wikipedia.org/wiki/List_of_colors
//                     and related pages:
//                     https://en.wikipedia.org/wiki/List_of_Crayola_crayon_colors
//                     https://en.wikipedia.org/wiki/X11_color_names
//                     https://en.wikipedia.org/wiki/Web_colors
//
//                     LEGO™ colors
//                     http://www.peeron.com/cgi-bin/invcgis/colorguide.cgi
//                     
//

#ifndef(farger_Inc_Temp)
#declare farger_Inc_Temp = version;
#version 3.7;

// Where the color definition is the same as in the POV-Ray color.inc include file,
// the color name will point to the POV-Ray color definition,
// so we need to make sure that file is included
#ifndef(Colors_Inc_Temp)
    #include "colors.inc"
#end

#ifdef(View_POV_Include_Stack)
    #debug "including farger.inc\n"
#end

// Crayola crayon colors
#declare Crayola_Absolute_Zero = srgb <0, 0.282352941, 0.729411765>;
#declare Crayola_Acid_Wash_Jeans = srgb <0.360784314, 0.698039216, 0.77254902>;
#declare Crayola_Alloy_Orange = srgb <0.768627451, 0.384313725, 0.062745098>;
#declare Crayola_Almond = srgb <0.933333333, 0.850980392, 0.768627451>;
#declare Crayola_Amethyst = srgb <0.392156863, 0.376470588, 0.603921569>;
#declare Crayola_Antique_Brass = srgb <0.784313725, 0.541176471, 0.396078431>;
#declare Crayola_Apricot = srgb <0.992156863, 0.835294118, 0.694117647>;
#declare Crayola_Aqua_Pearl = srgb <0.37254902, 0.745098039, 0.843137255>;
#declare Crayola_Aquamarine = srgb <0.584313725, 0.878431373, 0.909803922>;
#declare Crayola_Asparagus = srgb <0.482352941, 0.62745098, 0.356862745>;
#declare Crayola_Atomic_Tangerine = srgb <1, 0.6, 0.4>;
#declare Crayola_Aztec_Gold = srgb <0.764705882, 0.6, 0.325490196>;
#declare Crayola_Banana_Mania = srgb <0.984313725, 0.905882353, 0.698039216>;
#declare Crayola_Bdazzled_Blue = srgb <0.180392157, 0.345098039, 0.580392157>;
#declare Crayola_Beaver = srgb <0.57254902, 0.435294118, 0.356862745>;
#declare Crayola_Big_Dip_O_Ruby = srgb <0.611764706, 0.145098039, 0.258823529>;
#declare Crayola_Big_Foot_Feet = srgb <0.850980392, 0.603921569, 0.423529412>;
#declare Crayola_Bittersweet = srgb <0.996078431, 0.435294118, 0.368627451>;
#declare Crayola_Bittersweet_Shimmer = srgb <0.749019608, 0.309803922, 0.317647059>;
#declare Crayola_Black_Coral_Pearl = srgb <0.329411765, 0.384313725, 0.435294118>;
#declare Crayola_Black_Shadows = srgb <0.749019608, 0.68627451, 0.698039216>;
#declare Crayola_Blast_Off_Bronze = srgb <0.647058824, 0.443137255, 0.392156863>;
#declare Crayola_Blue_Bell = srgb <0.6, 0.6, 0.8>;
#declare Crayola_Blue_Gray = srgb <0.784313725, 0.784313725, 0.803921569>;
#declare Crayola_Blue_Green = srgb <0, 0.584313725, 0.717647059>;
#declare Crayola_Blue_I = srgb <0.180392157, 0.705882353, 0.901960784>;
#declare Crayola_Blue_II = srgb <0.270588235, 0.439215686, 0.901960784>;
#declare Crayola_Blue_III = srgb <0, 0.4, 1>;
#declare Crayola_Blue_Jeans = srgb <0.364705882, 0.678431373, 0.925490196>;
#declare Crayola_Blue_Violet = srgb <0.392156863, 0.337254902, 0.717647059>;
#declare Crayola_Bluetiful = srgb <0.235294118, 0.411764706, 0.905882353>;
#declare Crayola_Blush = srgb <0.858823529, 0.31372549, 0.474509804>;
#declare Crayola_Booger_Buster = srgb <0.925490196, 0.921568627, 0.741176471>;
#declare Crayola_Brick_Red = srgb <0.776470588, 0.176470588, 0.258823529>;
#declare Crayola_Bright_Yellow = srgb <1, 0.666666667, 0.11372549>;
#declare Crayola_Brilliant_Rose = srgb <0.901960784, 0.403921569, 0.807843137>;
#declare Crayola_Brown = srgb <0.68627451, 0.349019608, 0.243137255>;
#declare Crayola_Brown_Sugar = srgb <0.68627451, 0.431372549, 0.301960784>;
#declare Crayola_Burnished_Brown = srgb <0.631372549, 0.478431373, 0.454901961>;
#declare Crayola_Burnt_Orange = srgb <1, 0.439215686, 0.203921569>;
#declare Crayola_Burnt_Sienna = srgb <0.91372549, 0.454901961, 0.317647059>;
#declare Crayola_Burnt_Umber = srgb <0.501960784, 0.333333333, 0.2>;
#declare Crayola_Cadet_Blue = srgb <0.662745098, 0.698039216, 0.764705882>;
#declare Crayola_Canary = srgb <1, 1, 0.6>;
#declare Crayola_Caribbean_Green = srgb <0, 0.8, 0.6>;
#declare Crayola_Caribbean_Green_Pearl = srgb <0.415686275, 0.854901961, 0.556862745>;
#declare Crayola_Carmine = srgb <0.901960784, 0.180392157, 0.419607843>;
#declare Crayola_Carnation_Pink = srgb <1, 0.650980392, 0.788235294>;
#declare Crayola_Celestial_Blue = srgb <0.439215686, 0.439215686, 0.8>;
#declare Crayola_Cerise = srgb <0.854901961, 0.196078431, 0.529411765>;
#declare Crayola_Cerulean = srgb <0.007843137, 0.643137255, 0.82745098>;
#declare Crayola_Cerulean_Blue = srgb <0.2, 0.603921569, 0.8>;
#declare Crayola_Cerulean_Frost = srgb <0.42745098, 0.607843137, 0.764705882>;
#declare Crayola_Charcoal_Gray = srgb <0.450980392, 0.415686275, 0.384313725>;
#declare Crayola_Cheese_Grater = srgb <0.784313725, 0.623529412, 0.337254902>;
#declare Crayola_Cinnamon_Satin = srgb <0.803921569, 0.376470588, 0.494117647>;
#declare Crayola_Citrine = srgb <0.576470588, 0.215686275, 0.035294118>;
#declare Crayola_Cobalt_Blue = srgb <0.549019608, 0.564705882, 0.784313725>;
#declare Crayola_Cobalt_Cool = srgb <0.007843137, 0.541176471, 0.682352941>;
#declare Crayola_Copper = srgb <0.854901961, 0.541176471, 0.403921569>;
#declare Crayola_Copper_Penny = srgb <0.678431373, 0.435294118, 0.411764706>;
#declare Crayola_Cornflower = srgb <0.576470588, 0.8, 0.917647059>;
#declare Crayola_Cosmic_Cobalt = srgb <0.180392157, 0.176470588, 0.533333333>;
#declare Crayola_Cotton_Candy = srgb <1, 0.717647059, 0.835294118>;
#declare Crayola_Cultured_Pearl = srgb <0.960784314, 0.960784314, 0.960784314>;
#declare Crayola_Cyber_Grape = srgb <0.345098039, 0.258823529, 0.48627451>;
#declare Crayola_Dandelion = srgb <0.996078431, 0.847058824, 0.364705882>;
#declare Crayola_Dark_Venetian_Red = srgb <0.701960784, 0.231372549, 0.141176471>;
#declare Crayola_Deep_Space_Sparkle = srgb <0.290196078, 0.392156863, 0.423529412>;
#declare Crayola_Denim = srgb <0.082352941, 0.376470588, 0.741176471>;
#declare Crayola_Denim_Blue = srgb <0.133333333, 0.262745098, 0.71372549>;
#declare Crayola_Desert_Sand = srgb <0.929411765, 0.788235294, 0.68627451>;
#declare Crayola_Eerie_Black = srgb <0.105882353, 0.105882353, 0.105882353>;
#declare Crayola_Eggplant = srgb <0.380392157, 0.250980392, 0.317647059>;
#declare Crayola_Electric_Lime = srgb <0.8, 1, 0>;
#declare Crayola_Emerald = srgb <0.078431373, 0.662745098, 0.537254902>;
#declare Crayola_English_Vermilion = srgb <0.8, 0.278431373, 0.294117647>;
#declare Crayola_Fern = srgb <0.388235294, 0.717647059, 0.423529412>;
#declare Crayola_Fiery_Rose = srgb <0.933333333, 0.203921569, 0.823529412>;
#declare Crayola_Forest_Green = srgb <0.37254902, 0.654901961, 0.466666667>;
#declare Crayola_Frostbite = srgb <0.91372549, 0.211764706, 0.654901961>;
#declare Crayola_Fuchsia = srgb <0.756862745, 0.329411765, 0.756862745>;
#declare Crayola_Fuzzy_Wuzzy = srgb <0.529411765, 0.258823529, 0.121568627>;
#declare Crayola_Giants_Club = srgb <0.725490196, 0.305882353, 0.282352941>;
#declare Crayola_Glossy_Grape = srgb <0.670588235, 0.57254902, 0.701960784>;
#declare Crayola_Gold_Fusion = srgb <0.521568627, 0.458823529, 0.305882353>;
#declare Crayola_Gold_I = srgb <0.57254902, 0.57254902, 0.431372549>;
#declare Crayola_Gold_II = srgb <0.901960784, 0.745098039, 0.541176471>;
#declare Crayola_Gold_Medal = srgb <0.77254902, 0.737254902, 0.258823529>;
#declare Crayola_Goldenrod = srgb <0.988235294, 0.839215686, 0.403921569>;
#declare Crayola_Granite_Gray = srgb <0.403921569, 0.403921569, 0.403921569>;
#declare Crayola_Granny_Smith_Apple = srgb <0.615686275, 0.878431373, 0.576470588>;
#declare Crayola_Gray = srgb <0.545098039, 0.525490196, 0.501960784>;
#declare Crayola_Green = srgb <0.22745098, 0.650980392, 0.333333333>;
#declare Crayola_Green_Blue = srgb <0.156862745, 0.529411765, 0.784313725>;
#declare Crayola_Green_Lizard = srgb <0.654901961, 0.956862745, 0.196078431>;
#declare Crayola_Green_Sheen = srgb <0.431372549, 0.682352941, 0.631372549>;
#declare Crayola_Green_Yellow = srgb <0.945098039, 0.905882353, 0.533333333>;
#declare Crayola_Hot_Magenta = srgb <1, 0, 0.8>;
#declare Crayola_Illuminating_Emerald = srgb <0.192156863, 0.568627451, 0.466666667>;
#declare Crayola_Inchworm = srgb <0.68627451, 0.890196078, 0.074509804>;
#declare Crayola_Indian_Red = srgb <0.725490196, 0.305882353, 0.282352941>;
#declare Crayola_Indigo = srgb <0.309803922, 0.411764706, 0.776470588>;
#declare Crayola_Iron_Indigo = srgb <0.094117647, 0.309803922, 0.631372549>;
#declare Crayola_Jade = srgb <0.274509804, 0.603921569, 0.517647059>;
#declare Crayola_Jasper = srgb <0.815686275, 0.325490196, 0.250980392>;
#declare Crayola_Jazzberry_Jam = srgb <0.647058824, 0.043137255, 0.368627451>;
#declare Crayola_Jungle_Green = srgb <0.160784314, 0.670588235, 0.529411765>;
#declare Crayola_Key_Lime_Pearl = srgb <0.909803922, 0.956862745, 0.549019608>;
#declare Crayola_Lapis_Lazuli = srgb <0.262745098, 0.423529412, 0.725490196>;
#declare Crayola_Laser_Lemon = srgb <1, 1, 0.4>;
#declare Crayola_Lavender_I = srgb <0.749019608, 0.560784314, 0.8>;
#declare Crayola_Lavender_II = srgb <0.984313725, 0.682352941, 0.823529412>;
#declare Crayola_Lemon_Yellow_II = srgb <1, 1, 0.623529412>;
#declare Crayola_Light_Blue = srgb <0.560784314, 0.847058824, 0.847058824>;
#declare Crayola_Light_Chrome_Green = srgb <0.745098039, 0.901960784, 0.294117647>;
#declare Crayola_Light_Venetian_Red = srgb <0.901960784, 0.450980392, 0.360784314>;
#declare Crayola_Lilac_Luster = srgb <0.682352941, 0.596078431, 0.666666667>;
#declare Crayola_Macaroni_and_Cheese = srgb <1, 0.725490196, 0.482352941>;
#declare Crayola_Madder_Lake = srgb <0.8, 0.2, 0.211764706>;
#declare Crayola_Magenta = srgb <0.964705882, 0.325490196, 0.650980392>;
#declare Crayola_Magnetic_Magenta = srgb <0.749019608, 0.223529412, 0.505882353>;
#declare Crayola_Mahogany = srgb <0.792156863, 0.203921569, 0.207843137>;
#declare Crayola_Maize = srgb <0.949019608, 0.776470588, 0.28627451>;
#declare Crayola_Malachite = srgb <0.274509804, 0.580392157, 0.588235294>;
#declare Crayola_Manatee = srgb <0.552941176, 0.564705882, 0.631372549>;
#declare Crayola_Mandarin_Pearl = srgb <0.952941176, 0.478431373, 0.282352941>;
#declare Crayola_Mango_Tango = srgb <0.905882353, 0.447058824, 0>;
#declare Crayola_Maroon = srgb <0.764705882, 0.129411765, 0.282352941>;
#declare Crayola_Maroon = srgb <0.764705882, 0.129411765, 0.282352941>;
#declare Crayola_Mauvelous = srgb <0.941176471, 0.568627451, 0.662745098>;
#declare Crayola_Maximum_Blue = srgb <0.278431373, 0.670588235, 0.8>;
#declare Crayola_Maximum_Blue_Green = srgb <0.188235294, 0.749019608, 0.749019608>;
#declare Crayola_Maximum_Blue_Purple = srgb <0.674509804, 0.674509804, 0.901960784>;
#declare Crayola_Maximum_Green = srgb <0.368627451, 0.549019608, 0.192156863>;
#declare Crayola_Maximum_Green_Yellow = srgb <0.850980392, 0.901960784, 0.31372549>;
#declare Crayola_Maximum_Purple = srgb <0.450980392, 0.2, 0.501960784>;
#declare Crayola_Maximum_Red = srgb <0.850980392, 0.129411765, 0.129411765>;
#declare Crayola_Maximum_Red_Purple = srgb <0.650980392, 0.22745098, 0.474509804>;
#declare Crayola_Maximum_Yellow = srgb <0.980392157, 0.980392157, 0.215686275>;
#declare Crayola_Maximum_Yellow_Red = srgb <0.949019608, 0.729411765, 0.28627451>;
#declare Crayola_Medium_Chrome_Green = srgb <0.423529412, 0.650980392, 0.48627451>;
#declare Crayola_Medium_Rose = srgb <0.850980392, 0.423529412, 0.745098039>;
#declare Crayola_Medium_Violet = srgb <0.560784314, 0.278431373, 0.701960784>;
#declare Crayola_Melon = srgb <0.996078431, 0.729411765, 0.678431373>;
#declare Crayola_Metallic_Seaweed = srgb <0.039215686, 0.494117647, 0.549019608>;
#declare Crayola_Middle_Blue = srgb <0.494117647, 0.831372549, 0.901960784>;
#declare Crayola_Middle_Blue_Green = srgb <0.552941176, 0.850980392, 0.8>;
#declare Crayola_Middle_Blue_Purple = srgb <0.545098039, 0.447058824, 0.745098039>;
#declare Crayola_Middle_Green = srgb <0.301960784, 0.549019608, 0.341176471>;
#declare Crayola_Middle_Green_Yellow = srgb <0.674509804, 0.749019608, 0.376470588>;
#declare Crayola_Middle_Purple = srgb <0.850980392, 0.509803922, 0.709803922>;
#declare Crayola_Middle_Red = srgb <0.898039216, 0.556862745, 0.450980392>;
#declare Crayola_Middle_Red_Purple = srgb <0.647058824, 0.325490196, 0.325490196>;
#declare Crayola_Middle_Yellow = srgb <1, 0.921568627, 0>;
#declare Crayola_Middle_Yellow_Red = srgb <0.925490196, 0.674509804, 0.462745098>;
#declare Crayola_Midnight_Blue = srgb <0, 0.2, 0.4>;
#declare Crayola_Midnight_Pearl = srgb <0.439215686, 0.149019608, 0.439215686>;
#declare Crayola_Misty_Moss = srgb <0.733333333, 0.705882353, 0.466666667>;
#declare Crayola_Moonstone = srgb <0.22745098, 0.658823529, 0.756862745>;
#declare Crayola_Mountain_Meadow = srgb <0.101960784, 0.701960784, 0.521568627>;
#declare Crayola_Mulberry = srgb <0.784313725, 0.31372549, 0.607843137>;
#declare Crayola_Mummys_Tomb = srgb <0.545098039, 0.525490196, 0.501960784>;
#declare Crayola_Mystic_Maroon = srgb <0.678431373, 0.262745098, 0.474509804>;
#declare Crayola_Mystic_Pearl = srgb <0.839215686, 0.321568627, 0.509803922>;
#declare Crayola_Navy_Blue = srgb <0, 0.4, 0.8>;
#declare Crayola_Neon_Carrot = srgb <1, 0.6, 0.2>;
#declare Crayola_Ocean_Blue_Pearl = srgb <0.309803922, 0.258823529, 0.709803922>;
#declare Crayola_Ocean_Green_Pearl = srgb <0.282352941, 0.749019608, 0.568627451>;
#declare Crayola_Olive_Green = srgb <0.709803922, 0.701960784, 0.360784314>;
#declare Crayola_Onyx = srgb <0.207843137, 0.219607843, 0.223529412>;
#declare Crayola_Orange = srgb <1, 0.533333333, 0.2>;
#declare Crayola_Orange_Red = srgb <1, 0.325490196, 0.28627451>;
#declare Crayola_Orange_Soda = srgb <0.980392157, 0.356862745, 0.239215686>;
#declare Crayola_Orange_Yellow = srgb <0.97254902, 0.835294118, 0.407843137>;
#declare Crayola_Orchid = srgb <0.88627451, 0.611764706, 0.823529412>;
#declare Crayola_Orchid_Pearl = srgb <0.482352941, 0.258823529, 0.349019608>;
#declare Crayola_Outer_Space = srgb <0.176470588, 0.219607843, 0.22745098>;
#declare Crayola_Outrageous_Orange = srgb <1, 0.376470588, 0.215686275>;
#declare Crayola_Pacific_Blue = srgb <0, 0.615686275, 0.768627451>;
#declare Crayola_Peach = srgb <1, 0.796078431, 0.643137255>;
#declare Crayola_Pearly_Purple = srgb <0.717647059, 0.407843137, 0.635294118>;
#declare Crayola_Peridot = srgb <0.670588235, 0.678431373, 0.282352941>;
#declare Crayola_Periwinkle = srgb <0.764705882, 0.803921569, 0.901960784>;
#declare Crayola_Permanent_Geranium_Lake = srgb <0.882352941, 0.17254902, 0.17254902>;
#declare Crayola_Petrified_Forest = srgb <0, 0.356862745, 0.223529412>;
#declare Crayola_Pewter_Blue = srgb <0.545098039, 0.658823529, 0.717647059>;
#declare Crayola_Piggy_Pink = srgb <0.992156863, 0.843137255, 0.894117647>;
#declare Crayola_Pine_Green = srgb <0.003921569, 0.470588235, 0.435294118>;
#declare Crayola_Pink_Flamingo = srgb <0.988235294, 0.454901961, 0.992156863>;
#declare Crayola_Pink_Pearl = srgb <0.690196078, 0.439215686, 0.501960784>;
#declare Crayola_Pink_Sherbert = srgb <0.968627451, 0.639215686, 0.556862745>;
#declare Crayola_Pixie_Powder = srgb <0.392156863, 0.337254902, 0.717647059>;
#declare Crayola_Plum = srgb <0.556862745, 0.192156863, 0.474509804>;
#declare Crayola_Plump_Purple = srgb <0.349019608, 0.274509804, 0.698039216>;
#declare Crayola_Polished_Pine = srgb <0.364705882, 0.643137255, 0.576470588>;
#declare Crayola_Purple_Heart = srgb <0.396078431, 0.176470588, 0.756862745>;
#declare Crayola_Purple_Mountains_Majesty = srgb <0.839215686, 0.682352941, 0.866666667>;
#declare Crayola_Purple_Plum = srgb <0.611764706, 0.317647059, 0.71372549>;
#declare Crayola_Quick_Silver = srgb <0.650980392, 0.650980392, 0.650980392>;
#declare Crayola_Radical_Red = srgb <1, 0.207843137, 0.368627451>;
#declare Crayola_Raw_Sienna = srgb <0.823529412, 0.490196078, 0.274509804>;
#declare Crayola_Raw_Sienna_I = srgb <0.901960784, 0.737254902, 0.360784314>;
#declare Crayola_Raw_Umber = srgb <0.4, 0.321568627, 0.2>;
#declare Crayola_Razzmatazz = srgb <0.890196078, 0.043137255, 0.360784314>;
#declare Crayola_Razzmic_Berry = srgb <0.552941176, 0.305882353, 0.521568627>;
#declare Crayola_Red = srgb <0.929411765, 0.039215686, 0.247058824>;
#declare Crayola_Red = srgb <0.929411765, 0.039215686, 0.247058824>;
#declare Crayola_Red_Orange = srgb <1, 0.407843137, 0.121568627>;
#declare Crayola_Red_Salsa = srgb <0.992156863, 0.22745098, 0.290196078>;
#declare Crayola_Red_Violet = srgb <0.733333333, 0.2, 0.521568627>;
#declare Crayola_Robins_Egg_Blue = srgb <0, 0.8, 0.8>;
#declare Crayola_Robot_Canary = srgb <0.611764706, 0.48627451, 0.219607843>;
#declare Crayola_Rose_Dust = srgb <0.619607843, 0.368627451, 0.435294118>;
#declare Crayola_Rose_Gold = srgb <0.784313725, 0.549019608, 0.643137255>;
#declare Crayola_Rose_Pearl = srgb <0.941176471, 0.219607843, 0.396078431>;
#declare Crayola_Rose_Quartz = srgb <0.741176471, 0.333333333, 0.611764706>;
#declare Crayola_Royal_Purple = srgb <0.419607843, 0.247058824, 0.62745098>;
#declare Crayola_Ruby = srgb <0.666666667, 0.250980392, 0.411764706>;
#declare Crayola_Rusty_Red = srgb <0.854901961, 0.17254902, 0.262745098>;
#declare Crayola_Salmon = srgb <1, 0.568627451, 0.643137255>;
#declare Crayola_Salmon_Pearl = srgb <0.945098039, 0.266666667, 0.290196078>;
#declare Crayola_Sapphire = srgb <0.176470588, 0.364705882, 0.631372549>;
#declare Crayola_Sasquatch_Socks = srgb <0.968627451, 0.274509804, 0.541176471>;
#declare Crayola_Scarlet = srgb <0.992156863, 0.054901961, 0.207843137>;
#declare Crayola_Screamin_Green = srgb <0.4, 1, 0.4>;
#declare Crayola_Sea_Green = srgb <0.576470588, 0.874509804, 0.721568627>;
#declare Crayola_Sea_Serpent = srgb <0, 0.8, 0.8>;
#declare Crayola_Sepia = srgb <0.619607843, 0.356862745, 0.250980392>;
#declare Crayola_Shadow = srgb <0.51372549, 0.439215686, 0.31372549>;
#declare Crayola_Shadow_Blue = srgb <0.466666667, 0.545098039, 0.647058824>;
#declare Crayola_Shamrock = srgb <0.2, 0.8, 0.6>;
#declare Crayola_Sheen_Green = srgb <0.560784314, 0.831372549, 0>;
#declare Crayola_Shimmering_Blush = srgb <0.850980392, 0.525490196, 0.584313725>;
#declare Crayola_Shiny_Shamrock = srgb <0.37254902, 0.654901961, 0.470588235>;
#declare Crayola_Shocking_Pink = srgb <1, 0.431372549, 1>;
#declare Crayola_Silver = srgb <0.788235294, 0.752941176, 0.733333333>;
#declare Crayola_Sizzling_Red = srgb <1, 0.219607843, 0.333333333>;
#declare Crayola_Sky_Blue = srgb <0.462745098, 0.843137255, 0.917647059>;
#declare Crayola_Slimy_Green = srgb <0.160784314, 0.588235294, 0.090196078>;
#declare Crayola_Smokey_Topaz = srgb <0.51372549, 0.164705882, 0.050980392>;
#declare Crayola_Sonic_Silver = srgb <0.458823529, 0.458823529, 0.458823529>;
#declare Crayola_Spring_Frost = srgb <0.4, 1, 0.4>;
#declare Crayola_Spring_Green = srgb <0.925490196, 0.921568627, 0.741176471>;
#declare Crayola_Steel_Blue = srgb <0, 0.505882353, 0.670588235>;
#declare Crayola_Steel_Teal = srgb <0.37254902, 0.541176471, 0.545098039>;
#declare Crayola_Sugar_Plum = srgb <0.568627451, 0.305882353, 0.458823529>;
#declare Crayola_Sunburnt_Cyclops = srgb <0.905882353, 0.447058824, 0>;
#declare Crayola_Sunglow = srgb <1, 0.8, 0.2>;
#declare Crayola_Sunny_Pearl = srgb <0.949019608, 0.949019608, 0.478431373>;
#declare Crayola_Sunset_Orange = srgb <0.996078431, 0.298039216, 0.250980392>;
#declare Crayola_Sunset_Pearl = srgb <0.945098039, 0.8, 0.474509804>;
#declare Crayola_Sweet_Brown = srgb <0.658823529, 0.215686275, 0.192156863>;
#declare Crayola_Tan = srgb <0.980392157, 0.615686275, 0.352941176>;
#declare Crayola_Tart_Orange = srgb <0.984313725, 0.301960784, 0.274509804>;
#declare Crayola_Teal_Blue = srgb <0, 0.501960784, 0.501960784>;
#declare Crayola_Thistle = srgb <0.921568627, 0.690196078, 0.843137255>;
#declare Crayola_Tickle_Me_Pink = srgb <0.988235294, 0.501960784, 0.647058824>;
#declare Crayola_Tickle_Me_Pink = srgb <0.988235294, 0.501960784, 0.647058824>;
#declare Crayola_Tigers_Eye = srgb <0.709803922, 0.411764706, 0.090196078>;
#declare Crayola_Timberwolf = srgb <0.850980392, 0.839215686, 0.811764706>;
#declare Crayola_Tropical_Rain_Forest = srgb <0, 0.458823529, 0.368627451>;
#declare Crayola_Tumbleweed = srgb <0.870588235, 0.650980392, 0.505882353>;
#declare Crayola_Turquoise_Blue = srgb <0.423529412, 0.854901961, 0.905882353>;
#declare Crayola_Turquoise_Pearl = srgb <0.231372549, 0.737254902, 0.815686275>;
#declare Crayola_Twilight_Lavender = srgb <0.541176471, 0.28627451, 0.419607843>;
#declare Crayola_Ultramarine_Blue = srgb <0.247058824, 0.149019608, 0.749019608>;
#declare Crayola_Van_Dyke_Brown = srgb <0.4, 0.258823529, 0.156862745>;
#declare Crayola_Venetian_Red = srgb <0.8, 0.333333333, 0.239215686>;
#declare Crayola_Violet_Blue = srgb <0.462745098, 0.431372549, 0.784313725>;
#declare Crayola_Violet_I = srgb <0.450980392, 0.180392157, 0.423529412>;
#declare Crayola_Violet_II = srgb <0.51372549, 0.349019608, 0.639215686>;
#declare Crayola_Violet_Red = srgb <0.968627451, 0.274509804, 0.541176471>;
#declare Crayola_Vivid_Tangerine = srgb <1, 0.6, 0.501960784>;
#declare Crayola_Vivid_Violet = srgb <0.501960784, 0.215686275, 0.564705882>;
#declare Crayola_Wild_Blue_Yonder = srgb <0.478431373, 0.537254902, 0.721568627>;
#declare Crayola_Wild_Strawberry = srgb <1, 0.2, 0.6>;
#declare Crayola_Wild_Watermelon = srgb <0.992156863, 0.356862745, 0.470588235>;
#declare Crayola_Winter_Wizard = srgb <0.462745098, 0.843137255, 0.917647059>;
#declare Crayola_Wintergreen_Dream = srgb <0.337254902, 0.533333333, 0.490196078>;
#declare Crayola_Wisteria = srgb <0.788235294, 0.62745098, 0.862745098>;
#declare Crayola_Yellow = srgb <0.984313725, 0.909803922, 0.439215686>;
#declare Crayola_Yellow_Green = srgb <0.77254902, 0.882352941, 0.478431373>;
#declare Crayola_Yellow_Green = srgb <0.77254902, 0.882352941, 0.478431373>;
#declare Crayola_Yellow_Orange = srgb <1, 0.682352941, 0.258823529>;
#declare Crayola_Yellow_Sunshine = srgb <1, 0.968627451, 0>;

// Alternative Crayola color names
#declare Crayola_Azure_Blue_1949_1958 = Crayola_Blue_I;
#declare Crayola_Baby_Powder = White;
#declare Crayola_Babys_Powder = White;
#declare Crayola_Banana = Crayola_Dandelion;
#declare Crayola_Baseball_Mitt = Crayola_Burnt_Sienna;
#declare Crayola_Black = Black;
#declare Crayola_Blue_Green_1930_1958 = Crayola_Maximum_Blue;
#declare Crayola_Blue_Violet_1930_1958 = Crayola_Violet_Blue;
#declare Crayola_Blueberry = Crayola_Blue_II;
#declare Crayola_Brink_Pink_1998_2005 = Crayola_Pink_Sherbert;
#declare Crayola_Brown_1903_1935 = Crayola_Van_Dyke_Brown;
#declare Crayola_Bubble_Bath = Crayola_Tickle_Me_Pink;
#declare Crayola_Bubble_Gum = Crayola_Tickle_Me_Pink;
#declare Crayola_Carmine_Red_1949_1958 = Crayola_Carmine;
#declare Crayola_Cedar_Chest = Crayola_Mahogany;
#declare Crayola_Celestial_Blue_1935_1949 = Crayola_Blue_I;
#declare Crayola_Chartreuse_1972_1990 = Crayola_Laser_Lemon;
#declare Crayola_Cherry = Crayola_Maroon;
#declare Crayola_Chestnut_1999 = Crayola_Indian_Red;
#declare Crayola_Chocolate = Crayola_Brown;
#declare Crayola_Chrome_Green_Dark = Crayola_Pine_Green;
#declare Crayola_Chrome_Green_Light = Crayola_Light_Chrome_Green;
#declare Crayola_Chrome_Green_Medium_1903_1939 = Crayola_Medium_Chrome_Green;
#declare Crayola_Chrome_Yellow_Light = Crayola_Lemon_Yellow_II;
#declare Crayola_Chrome_Yellow_Light = Crayola_Lemon_Yellow_II;
#declare Crayola_Coconut = White;
#declare Crayola_Cranberry_1998_2005 = Crayola_Blush;
#declare Crayola_Daffodil = Crayola_Yellow;
#declare Crayola_Dark_Chrome_Green = Crayola_Pine_Green;
#declare Crayola_Dark_Green_1903_1949 = Crayola_Pine_Green;
#declare Crayola_Dark_Green_1949_1958 = Crayola_Forest_Green;
#declare Crayola_Dark_Red_1949_1958 = Crayola_Maroon;
#declare Crayola_Dirt = Crayola_Sepia;
#declare Crayola_Earthworm = Crayola_Brick_Red;
#declare Crayola_Eucalyptus = Crayola_Jungle_Green;
#declare Crayola_Flesh_1949_1956 = Crayola_Peach;
#declare Crayola_Flesh_1958_1962 = Crayola_Peach;
#declare Crayola_Flesh_Tint_1903_1949 = Crayola_Peach;
#declare Crayola_Flower_Shop = Crayola_Wisteria;
#declare Crayola_Fresh_Air = Crayola_Sky_Blue;
#declare Crayola_Fuzzy_Wuzzy_Brown_1998_2005 = Crayola_Fuzzy_Wuzzy;
#declare Crayola_Gargoyle_Gas = Crayola_Dandelion;
#declare Crayola_Gold_Ochre_1903_1958 = Crayola_Maize;
#declare Crayola_Golden_Ochre = Crayola_Maize;
#declare Crayola_Grandmas_Perfume = Crayola_Orange;
#declare Crayola_Grape = Crayola_Violet_II;
#declare Crayola_Grey = Crayola_Gray;
#declare Crayola_Heat_Wave = Crayola_Wild_Watermelon;
#declare Crayola_Jelly_Bean = Crayola_Orange;
#declare Crayola_Koala_Tree = Crayola_Jungle_Green;
#declare Crayola_Leather_Jacket = Crayola_Black;
#declare Crayola_Lemon = Crayola_Yellow;
#declare Crayola_Lemon_Glacier = Crayola_Laser_Lemon;
#declare Crayola_Licorice = Crayola_Black;
#declare Crayola_Light_Chrome_Yellow = Crayola_Lemon_Yellow_II;
#declare Crayola_Light_Green_1903_1935 = Crayola_Light_Chrome_Green;
#declare Crayola_Light_Green_1949_1958 = Crayola_Sea_Green;
#declare Crayola_Light_Magenta_1949_1958 = Crayola_Thistle;
#declare Crayola_Light_Turquoise_Blue_1949_1958 = Crayola_Aquamarine;
#declare Crayola_Light_Yellow_1903_1958 = Crayola_Lemon_Yellow_II;
#declare Crayola_Lilac = Crayola_Wisteria;
#declare Crayola_Lime = Crayola_Yellow_Green;
#declare Crayola_Lumber = Crayola_Apricot;
#declare Crayola_Macaroni_n_Cheese = Crayola_Macaroni_and_Cheese;
#declare Crayola_Medium_Blue_1949_1958 = Crayola_Blue_II;
#declare Crayola_Medium_Chrome_Yellow_1903 = Crayola_Goldenrod;
#declare Crayola_Medium_Green_1903_1939 = Crayola_Medium_Chrome_Green;
#declare Crayola_Medium_Orange_1949_1958 = Crayola_Middle_Yellow_Red;
#declare Crayola_Medium_Red_Violet_1949_1958 = Crayola_Orchid;
#declare Crayola_Medium_Yellow_1903_1958 = Crayola_Goldenrod;
#declare Crayola_Middle_Blue_Green_1949_1958 = Crayola_Blue_Green;
#declare Crayola_Middle_Grey_1926_1944 = Crayola_Gray;
#declare Crayola_Neutral_Grey_1930_1956 = Crayola_Gray;
#declare Crayola_New_Car = Crayola_Blue_III;
#declare Crayola_New_Sneakers = Crayola_Black;
#declare Crayola_Ogre_Odor = Crayola_Red_Orange;
#declare Crayola_Permanent_Magenta_1903 = Crayola_Magenta;
#declare Crayola_Pet_Shop = Crayola_Brown;
#declare Crayola_Pig_Pink = Crayola_Piggy_Pink;
#declare Crayola_Pine = Crayola_Pine_Green;
#declare Crayola_Pine_Tree = Crayola_Pine_Green;
#declare Crayola_Pink_1903_1917 = Crayola_Carnation_Pink;
#declare Crayola_Pink_Beige_1956_1958 = Crayola_Peach;
#declare Crayola_Prussian_Blue_1903_1958 = Crayola_Midnight_Blue;
#declare Crayola_Purple_1903_1914 = Crayola_Violet_I;
#declare Crayola_Purple_Mountain_Majesty = Crayola_Purple_Mountains_Majesty;
#declare Crayola_Purple_Pizzazz = Crayola_Hot_Magenta;
#declare Crayola_Rose = Crayola_Red;
#declare Crayola_Rose_Pink_1903_1958 = Crayola_Carnation_Pink;
#declare Crayola_Saw_Dust = Crayola_Peach;
#declare Crayola_Shampoo = Crayola_Carnation_Pink;
#declare Crayola_Sharpening_Pencils = Crayola_Goldenrod;
#declare Crayola_Sizzling_Sunset = Crayola_Atomic_Tangerine;
#declare Crayola_Smashed_Pumpkin = Crayola_Orange;
#declare Crayola_Smell_The_Roses = Crayola_Red;
#declare Crayola_Smoke = Crayola_Gray;
#declare Crayola_Soap = Crayola_Periwinkle;
#declare Crayola_Strawberry = Crayola_Wild_Strawberry;
#declare Crayola_Sunny_Day = Crayola_Yellow;
#declare Crayola_Torch_Red_1998 = Crayola_Scarlet;
#declare Crayola_Tulip = Crayola_Orange;
#declare Crayola_Ultra_Green_1972_1990 = Crayola_Screamin_Green;
#declare Crayola_Ultra_Orange_1972_1990 = Crayola_Outrageous_Orange;
#declare Crayola_Ultra_Pink_1972_1990 = Crayola_Shocking_Pink;
#declare Crayola_Ultra_Red_1972_1990 = Crayola_Wild_Watermelon;
#declare Crayola_Ultra_Yellow_1972_1990 = Crayola_Atomic_Tangerine;
#declare Crayola_Unmellow_Yellow = Crayola_Laser_Lemon;
#declare Crayola_Venetian_Red_Dark = Crayola_Dark_Venetian_Red;
#declare Crayola_Venetian_Red_Light = Crayola_Light_Venetian_Red;
#declare Crayola_Vermillion = Crayola_English_Vermilion;
#declare Crayola_Violet = Crayola_Violet_II;
#declare Crayola_Violet_1949_1958 = Crayola_Blue_Violet;
#declare Crayola_Wash_The_Dog = Crayola_Dandelion;
#declare Crayola_White = White;
#declare Crayola_Winter_Sky = Crayola_Hot_Magenta;

// farge colors
#declare farge_Acid_Green = srgb <0.690196078, 0.749019608, 0.101960784>;
#declare farge_Aero = srgb <0.48627451, 0.725490196, 0.909803922>;
#declare farge_Aero_Blue = srgb <0.788235294, 1, 0.898039216>;
#declare farge_African_Violet = srgb <0.698039216, 0.517647059, 0.745098039>;
#declare farge_Air_Force_Blue_RAF = srgb <0.364705882, 0.541176471, 0.658823529>;
#declare farge_Air_Force_Blue_USAF = srgb <0, 0.188235294, 0.560784314>;
#declare farge_Air_Superiority_Blue = srgb <0.447058824, 0.62745098, 0.756862745>;
#declare farge_Alabama_Crimson = srgb <0.68627451, 0, 0.164705882>;
#declare farge_Alabaster = srgb <0.929411765, 0.917647059, 0.878431373>;
#declare farge_Alice_Blue = srgb <0.941176471, 0.97254902, 1>;
#declare farge_Alizarin_Crimson = srgb <0.890196078, 0.149019608, 0.211764706>;
#declare farge_Almond = srgb <0.937254902, 0.870588235, 0.803921569>;
#declare farge_Amaranth = srgb <0.898039216, 0.168627451, 0.31372549>;
#declare farge_Amaranth_M_n_P = srgb <0.623529412, 0.168627451, 0.407843137>;
#declare farge_Amaranth_Pink = srgb <0.945098039, 0.611764706, 0.733333333>;
#declare farge_Amaranth_Purple = srgb <0.670588235, 0.152941176, 0.309803922>;
#declare farge_Amaranth_Red = srgb <0.82745098, 0.129411765, 0.176470588>;
#declare farge_Amazon = srgb <0.231372549, 0.478431373, 0.341176471>;
#declare farge_Amber = srgb <1, 0.749019608, 0>;
#declare farge_Amber_SAE_ECE = srgb <1, 0.494117647, 0>;
#declare farge_American_Rose = srgb <1, 0.011764706, 0.243137255>;
#declare farge_Amethyst = srgb <0.6, 0.4, 0.8>;
#declare farge_Android_Green = srgb <0.643137255, 0.776470588, 0.223529412>;
#declare farge_Anti_Flash_White = srgb <0.949019608, 0.952941176, 0.956862745>;
#declare farge_Antique_Brass = srgb <0.803921569, 0.584313725, 0.458823529>;
#declare farge_Antique_Bronze = srgb <0.4, 0.364705882, 0.117647059>;
#declare farge_Antique_Fuchsia = srgb <0.568627451, 0.360784314, 0.51372549>;
#declare farge_Antique_Ruby = srgb <0.517647059, 0.105882353, 0.176470588>;
#declare farge_Antique_White = srgb <0.980392157, 0.921568627, 0.843137255>;
#declare farge_AO_English = srgb <0, 0.501960784, 0>;
#declare farge_Apple_Green = srgb <0.552941176, 0.71372549, 0>;
#declare farge_Apricot = srgb <0.984313725, 0.807843137, 0.694117647>;
#declare farge_Aquamarine = srgb <0.498039216, 1, 0.831372549>;
#declare farge_Arctic_Lime = srgb <0.815686275, 1, 0.078431373>;
#declare farge_Army_Green = srgb <0.294117647, 0.325490196, 0.125490196>;
#declare farge_Arsenic = srgb <0.231372549, 0.266666667, 0.294117647>;
#declare farge_Artichoke = srgb <0.560784314, 0.592156863, 0.474509804>;
#declare farge_Arylide_Yellow = srgb <0.91372549, 0.839215686, 0.419607843>;
#declare farge_Ash_Gray = srgb <0.698039216, 0.745098039, 0.709803922>;
#declare farge_Ash_Grey = srgb <0.698039216, 0.745098039, 0.709803922>;
#declare farge_Asparagus = srgb <0.529411765, 0.662745098, 0.419607843>;
#declare farge_Auburn = srgb <0.647058824, 0.164705882, 0.164705882>;
#declare farge_Aureolin = srgb <0.992156863, 0.933333333, 0>;
#declare farge_Aurometalsaurus = srgb <0.431372549, 0.498039216, 0.501960784>;
#declare farge_Avocado = srgb <0.337254902, 0.509803922, 0.011764706>;
#declare farge_Azure = srgb <0, 0.498039216, 1>;
#declare farge_Azure_Mist = srgb <0.941176471, 1, 1>;
#declare farge_Azureish_White = srgb <0.858823529, 0.91372549, 0.956862745>;
#declare farge_Baby_Blue = srgb <0.537254902, 0.811764706, 0.941176471>;
#declare farge_Baby_Blue_Eyes = srgb <0.631372549, 0.792156863, 0.945098039>;
#declare farge_Baby_Pink = srgb <0.956862745, 0.760784314, 0.760784314>;
#declare farge_Baby_Powder = srgb <0.996078431, 0.996078431, 0.980392157>;
#declare farge_Baker_Miller_Pink = srgb <1, 0.568627451, 0.68627451>;
#declare farge_Ball_Blue = srgb <0.129411765, 0.670588235, 0.803921569>;
#declare farge_Banana_Mania = srgb <0.980392157, 0.905882353, 0.709803922>;
#declare farge_Banana_Yellow = srgb <1, 0.882352941, 0.207843137>;
#declare farge_Bangladesh_Green = srgb <0, 0.415686275, 0.305882353>;
#declare farge_Barbie_Pink = srgb <0.854901961, 0.094117647, 0.517647059>;
#declare farge_Barn_Red = srgb <0.48627451, 0.039215686, 0.007843137>;
#declare farge_Battleship_Grey = srgb <0.517647059, 0.517647059, 0.509803922>;
#declare farge_Bazaar = srgb <0.596078431, 0.466666667, 0.482352941>;
#declare farge_Beau_Blue = srgb <0.737254902, 0.831372549, 0.901960784>;
#declare farge_Beaver = srgb <0.623529412, 0.505882353, 0.439215686>;
#declare farge_Beige = srgb <0.960784314, 0.960784314, 0.862745098>;
#declare farge_Bisque = srgb <1, 0.894117647, 0.768627451>;
#declare farge_Bistre = srgb <0.239215686, 0.168627451, 0.121568627>;
#declare farge_Bistre_Brown = srgb <0.588235294, 0.443137255, 0.090196078>;
#declare farge_Bitter_Lemon = srgb <0.792156863, 0.878431373, 0.050980392>;
#declare farge_Bitter_Lime = srgb <0.749019608, 1, 0>;
#declare farge_Black_Bean = srgb <0.239215686, 0.047058824, 0.007843137>;
#declare farge_Black_Chocolate = srgb <0.105882353, 0.094117647, 0.066666667>;
#declare farge_Black_Coffee = srgb <0.231372549, 0.184313725, 0.184313725>;
#declare farge_Black_Leather_Jacket = srgb <0.145098039, 0.207843137, 0.160784314>;
#declare farge_Black_Olive = srgb <0.231372549, 0.235294118, 0.211764706>;
#declare farge_Blanched_Almond = srgb <1, 0.921568627, 0.803921569>;
#declare farge_Bleu_De_France = srgb <0.192156863, 0.549019608, 0.905882353>;
#declare farge_Blizzard_Blue = srgb <0.674509804, 0.898039216, 0.933333333>;
#declare farge_Blond = srgb <0.980392157, 0.941176471, 0.745098039>;
#declare farge_Blood_Red = srgb <0.4, 0, 0>;
#declare farge_Blue_Bell = srgb <0.635294118, 0.635294118, 0.815686275>;
#declare farge_Blue_Gray = srgb <0.4, 0.6, 0.8>;
#declare farge_Blue_Green = srgb <0.050980392, 0.596078431, 0.729411765>;
#declare farge_Blue_Magenta_Violet = srgb <0.333333333, 0.207843137, 0.57254902>;
#declare farge_Blue_Munsell = srgb <0, 0.576470588, 0.68627451>;
#declare farge_Blue_NCS = srgb <0, 0.529411765, 0.741176471>;
#declare farge_Blue_Pantone = srgb <0, 0.094117647, 0.658823529>;
#declare farge_Blue_Pigment = srgb <0.2, 0.2, 0.6>;
#declare farge_Blue_RYB = srgb <0.007843137, 0.278431373, 0.996078431>;
#declare farge_Blue_Sapphire = srgb <0.070588235, 0.380392157, 0.501960784>;
#declare farge_Blue_Violet = srgb <0.541176471, 0.168627451, 0.88627451>;
#declare farge_Blue_Yonder = srgb <0.31372549, 0.447058824, 0.654901961>;
#declare farge_Blueberry = srgb <0.309803922, 0.525490196, 0.968627451>;
#declare farge_Bluebonnet = srgb <0.109803922, 0.109803922, 0.941176471>;
#declare farge_Blush = srgb <0.870588235, 0.364705882, 0.51372549>;
#declare farge_Bole = srgb <0.474509804, 0.266666667, 0.231372549>;
#declare farge_Bondi_Blue = srgb <0, 0.584313725, 0.71372549>;
#declare farge_Bone = srgb <0.890196078, 0.854901961, 0.788235294>;
#declare farge_Boston_University_Red = srgb <0.8, 0, 0>;
#declare farge_Bottle_Green = srgb <0, 0.415686275, 0.305882353>;
#declare farge_Boysenberry = srgb <0.529411765, 0.196078431, 0.376470588>;
#declare farge_Brandeis_Blue = srgb <0, 0.439215686, 1>;
#declare farge_Brandy = srgb <0.529411765, 0.254901961, 0.247058824>;
#declare farge_Brick_Red = srgb <0.796078431, 0.254901961, 0.329411765>;
#declare farge_Bright_Cerulean = srgb <0.11372549, 0.674509804, 0.839215686>;
#declare farge_Bright_Green = srgb <0.4, 1, 0>;
#declare farge_Bright_Lavender = srgb <0.749019608, 0.580392157, 0.894117647>;
#declare farge_Bright_Lilac = srgb <0.847058824, 0.568627451, 0.937254902>;
#declare farge_Bright_Maroon = srgb <0.764705882, 0.129411765, 0.282352941>;
#declare farge_Bright_Navy_Blue = srgb <0.098039216, 0.454901961, 0.823529412>;
#declare farge_Bright_Pink = srgb <1, 0, 0.498039216>;
#declare farge_Bright_Turquoise = srgb <0.031372549, 0.909803922, 0.870588235>;
#declare farge_Bright_Ube = srgb <0.819607843, 0.623529412, 0.909803922>;
#declare farge_Brilliant_Azure = srgb <0.2, 0.6, 1>;
#declare farge_Brilliant_Lavender = srgb <0.956862745, 0.733333333, 1>;
#declare farge_Brilliant_Rose = srgb <1, 0.333333333, 0.639215686>;
#declare farge_Brink_Pink = srgb <0.984313725, 0.376470588, 0.498039216>;
#declare farge_British_Racing_Green = srgb <0, 0.258823529, 0.145098039>;
#declare farge_Bronze = srgb <0.803921569, 0.498039216, 0.196078431>;
#declare farge_Bronze_Yellow = srgb <0.450980392, 0.439215686, 0>;
#declare farge_Brown = srgb <0.533333333, 0.329411765, 0.043137255>;
#declare farge_Brown_Nose = srgb <0.419607843, 0.266666667, 0.137254902>;
#declare farge_Brown_Traditional = srgb <0.588235294, 0.294117647, 0>;
#declare farge_Brown_Web = srgb <0.647058824, 0.164705882, 0.164705882>;
#declare farge_Brunswick_Green = srgb <0.105882353, 0.301960784, 0.243137255>;
#declare farge_Bubble_Gum = srgb <1, 0.756862745, 0.8>;
#declare farge_Bubbles = srgb <0.905882353, 0.996078431, 1>;
#declare farge_Bud_Green = srgb <0.482352941, 0.71372549, 0.380392157>;
#declare farge_Buff = srgb <0.941176471, 0.862745098, 0.509803922>;
#declare farge_Bulgarian_Rose = srgb <0.282352941, 0.023529412, 0.02745098>;
#declare farge_Burgundy = srgb <0.501960784, 0, 0.125490196>;
#declare farge_Burlywood = srgb <0.870588235, 0.721568627, 0.529411765>;
#declare farge_Burnt_Orange = srgb <0.8, 0.333333333, 0>;
#declare farge_Burnt_Umber = srgb <0.541176471, 0.2, 0.141176471>;
#declare farge_Byzantine = srgb <0.741176471, 0.2, 0.643137255>;
#declare farge_Byzantium = srgb <0.439215686, 0.160784314, 0.388235294>;
#declare farge_Cadet = srgb <0.325490196, 0.407843137, 0.447058824>;
#declare farge_Cadet_Blue = srgb <0.37254902, 0.619607843, 0.62745098>;
#declare farge_Cadet_Grey = srgb <0.568627451, 0.639215686, 0.690196078>;
#declare farge_Cadmium_Green = srgb <0, 0.419607843, 0.235294118>;
#declare farge_Cadmium_Orange = srgb <0.929411765, 0.529411765, 0.176470588>;
#declare farge_Cadmium_Red = srgb <0.890196078, 0, 0.133333333>;
#declare farge_Cadmium_Yellow = srgb <1, 0.964705882, 0>;
#declare farge_Cafe_Au_Lait = srgb <0.650980392, 0.482352941, 0.356862745>;
#declare farge_Cafe_Noir = srgb <0.294117647, 0.211764706, 0.129411765>;
#declare farge_Cal_Poly_Pomona_Green = srgb <0.117647059, 0.301960784, 0.168627451>;
#declare farge_Cambridge_Blue = srgb <0.639215686, 0.756862745, 0.678431373>;
#declare farge_Camel = srgb <0.756862745, 0.603921569, 0.419607843>;
#declare farge_Cameo_Pink = srgb <0.937254902, 0.733333333, 0.8>;
#declare farge_Camouflage_Green = srgb <0.470588235, 0.525490196, 0.419607843>;
#declare farge_Canary_Yellow = srgb <1, 0.937254902, 0>;
#declare farge_Candy_Apple_Red = srgb <1, 0.031372549, 0>;
#declare farge_Candy_Pink = srgb <0.894117647, 0.443137255, 0.478431373>;
#declare farge_Capri = srgb <0, 0.749019608, 1>;
#declare farge_Caput_Mortuum = srgb <0.349019608, 0.152941176, 0.125490196>;
#declare farge_Cardinal = srgb <0.768627451, 0.117647059, 0.22745098>;
#declare farge_Carmine = srgb <0.588235294, 0, 0.094117647>;
#declare farge_Carmine_M_and_P = srgb <0.843137255, 0, 0.250980392>;
#declare farge_Carmine_Pink = srgb <0.921568627, 0.298039216, 0.258823529>;
#declare farge_Carmine_Red = srgb <1, 0, 0.219607843>;
#declare farge_Carnelian = srgb <0.701960784, 0.105882353, 0.105882353>;
#declare farge_Carolina_Blue = srgb <0.337254902, 0.62745098, 0.82745098>;
#declare farge_Carrot_Orange = srgb <0.929411765, 0.568627451, 0.129411765>;
#declare farge_Castleton_Green = srgb <0, 0.337254902, 0.247058824>;
#declare farge_Catalina_Blue = srgb <0.023529412, 0.164705882, 0.470588235>;
#declare farge_Catawba = srgb <0.439215686, 0.211764706, 0.258823529>;
#declare farge_Cedar_Chest = srgb <0.788235294, 0.352941176, 0.28627451>;
#declare farge_Ceil = srgb <0.57254902, 0.631372549, 0.811764706>;
#declare farge_Celadon = srgb <0.674509804, 0.882352941, 0.68627451>;
#declare farge_Celadon_Blue = srgb <0, 0.482352941, 0.654901961>;
#declare farge_Celadon_Green = srgb <0.184313725, 0.517647059, 0.48627451>;
#declare farge_Celeste = srgb <0.698039216, 1, 1>;
#declare farge_Celestial_Blue = srgb <0.28627451, 0.592156863, 0.815686275>;
#declare farge_Celtic_Blue = srgb <0.141176471, 0.419607843, 0.807843137>;
#declare farge_Cerise = srgb <0.870588235, 0.192156863, 0.388235294>;
#declare farge_Cerise_Pink = srgb <0.925490196, 0.231372549, 0.51372549>;
#declare farge_Cerulean = srgb <0, 0.482352941, 0.654901961>;
#declare farge_Cerulean_Blue = srgb <0.164705882, 0.321568627, 0.745098039>;
#declare farge_CG_Blue = srgb <0, 0.478431373, 0.647058824>;
#declare farge_CG_Red = srgb <0.878431373, 0.235294118, 0.192156863>;
#declare farge_Chamoisee = srgb <0.62745098, 0.470588235, 0.352941176>;
#declare farge_Champagne = srgb <0.968627451, 0.905882353, 0.807843137>;
#declare farge_Champagne_Pink = srgb <0.945098039, 0.866666667, 0.811764706>;
#declare farge_Charcoal = srgb <0.211764706, 0.270588235, 0.309803922>;
#declare farge_Charleston_Green = srgb <0.137254902, 0.168627451, 0.168627451>;
#declare farge_Charm_Pink = srgb <0.901960784, 0.560784314, 0.674509804>;
#declare farge_Chartreuse_Traditional = srgb <0.874509804, 1, 0>;
#declare farge_Chartreuse_Web = srgb <0.498039216, 1, 0>;
#declare farge_Cherry = srgb <0.870588235, 0.192156863, 0.388235294>;
#declare farge_Cherry_Blossom_Pink = srgb <1, 0.717647059, 0.77254902>;
#declare farge_Chestnut = srgb <0.584313725, 0.270588235, 0.207843137>;
#declare farge_China_Pink = srgb <0.870588235, 0.435294118, 0.631372549>;
#declare farge_China_Rose = srgb <0.658823529, 0.317647059, 0.431372549>;
#declare farge_Chinese_Red = srgb <0.666666667, 0.219607843, 0.117647059>;
#declare farge_Chinese_Violet = srgb <0.521568627, 0.376470588, 0.533333333>;
#declare farge_Chinese_Yellow = srgb <1, 0.698039216, 0>;
#declare farge_Chocolate_Traditional = srgb <0.482352941, 0.247058824, 0>;
#declare farge_Chocolate_Web = srgb <0.823529412, 0.411764706, 0.117647059>;
#declare farge_Chrome_Yellow = srgb <1, 0.654901961, 0>;
#declare farge_Cinereous = srgb <0.596078431, 0.505882353, 0.482352941>;
#declare farge_Cinnabar = srgb <0.890196078, 0.258823529, 0.203921569>;
#declare farge_Cinnamon = srgb <0.823529412, 0.411764706, 0.117647059>;
#declare farge_Citrine = srgb <0.894117647, 0.815686275, 0.039215686>;
#declare farge_Citron = srgb <0.623529412, 0.662745098, 0.121568627>;
#declare farge_Claret = srgb <0.498039216, 0.090196078, 0.203921569>;
#declare farge_Classic_Rose = srgb <0.984313725, 0.8, 0.905882353>;
#declare farge_Cobalt = srgb <0, 0.278431373, 0.670588235>;
#declare farge_Cobalt_Blue = srgb <0, 0.278431373, 0.670588235>;
#declare farge_Cocoa_Brown = srgb <0.823529412, 0.411764706, 0.117647059>;
#declare farge_Coconut = srgb <0.588235294, 0.352941176, 0.243137255>;
#declare farge_Coffee = srgb <0.435294118, 0.305882353, 0.215686275>;
#declare farge_Color_Wheel_Blue_Green = srgb <0.023529412, 0.305882353, 0.250980392>;
#declare farge_Color_Wheel_Blue_Violet = srgb <0.301960784, 0.101960784, 0.498039216>;
#declare farge_Color_Wheel_Lime = srgb <0.749019608, 1, 0>;
#declare farge_Color_Wheel_Red_Orange = srgb <1, 0.270588235, 0>;
#declare farge_Color_Wheel_Red_Violet = srgb <0.57254902, 0.168627451, 0.243137255>;
#declare farge_Color_Wheel_Violet = srgb <0.498039216, 0, 1>;
#declare farge_Color_Wheel_Yellow_Green = srgb <0.188235294, 0.698039216, 0.101960784>;
#declare farge_Color_Wheel_Yellow_Orange = srgb <1, 0.584313725, 0.019607843>;
#declare farge_Columbia_Blue = srgb <0.725490196, 0.850980392, 0.921568627>;
#declare farge_Congo_Pink = srgb <0.97254902, 0.51372549, 0.474509804>;
#declare farge_Cool_Grey = srgb <0.549019608, 0.57254902, 0.674509804>;
#declare farge_Copper = srgb <0.721568627, 0.450980392, 0.2>;
#declare farge_Copper_Red = srgb <0.796078431, 0.42745098, 0.317647059>;
#declare farge_Copper_Rose = srgb <0.6, 0.4, 0.4>;
#declare farge_Coquelicot = srgb <1, 0.219607843, 0>;
#declare farge_Coral = srgb <1, 0.498039216, 0.31372549>;
#declare farge_Coral_Pink = srgb <0.97254902, 0.51372549, 0.474509804>;
#declare farge_Coral_Red = srgb <1, 0.250980392, 0.250980392>;
#declare farge_Cordovan = srgb <0.537254902, 0.247058824, 0.270588235>;
#declare farge_Corn = srgb <0.984313725, 0.925490196, 0.364705882>;
#declare farge_Cornell_Red = srgb <0.701960784, 0.105882353, 0.105882353>;
#declare farge_Cornflower_Blue = srgb <0.392156863, 0.584313725, 0.929411765>;
#declare farge_Cornsilk = srgb <1, 0.97254902, 0.862745098>;
#declare farge_Cosmic_Latte = srgb <1, 0.97254902, 0.905882353>;
#declare farge_Cotton_Candy = srgb <1, 0.737254902, 0.850980392>;
#declare farge_Coyote_Brown = srgb <0.505882353, 0.380392157, 0.235294118>;
#declare farge_Cream = srgb <1, 0.992156863, 0.815686275>;
#declare farge_Crimson = srgb <0.862745098, 0.078431373, 0.235294118>;
#declare farge_Crimson_Glory = srgb <0.745098039, 0, 0.196078431>;
#declare farge_Crimson_Red = srgb <0.6, 0, 0>;
#declare farge_Crimson_UA = srgb <0.619607843, 0.105882353, 0.196078431>;
#declare farge_Cyan_Azure = srgb <0.305882353, 0.509803922, 0.705882353>;
#declare farge_Cyan_Cobalt_Blue = srgb <0.156862745, 0.345098039, 0.611764706>;
#declare farge_Cyan_Cornflower_Blue = srgb <0.094117647, 0.545098039, 0.760784314>;
#declare farge_Cyan_Process = srgb <0, 0.717647059, 0.921568627>;
#declare farge_Cyber_Yellow = srgb <1, 0.82745098, 0>;
#declare farge_Cyclamen = srgb <0.960784314, 0.435294118, 0.631372549>;
#declare farge_Daffodil = srgb <1, 1, 0.192156863>;
#declare farge_Dandelion = srgb <0.941176471, 0.882352941, 0.188235294>;
#declare farge_Dark_Blue = srgb <0, 0, 0.545098039>;
#declare farge_Dark_Blue_Gray = srgb <0.4, 0.4, 0.6>;
#declare farge_Dark_Brown = srgb <0.396078431, 0.262745098, 0.129411765>;
#declare farge_Dark_Byzantium = srgb <0.364705882, 0.223529412, 0.329411765>;
#declare farge_Dark_Candy_Apple_Red = srgb <0.643137255, 0, 0>;
#declare farge_Dark_Cerulean = srgb <0.031372549, 0.270588235, 0.494117647>;
#declare farge_Dark_Chestnut = srgb <0.596078431, 0.411764706, 0.376470588>;
#declare farge_Dark_Coral = srgb <0.803921569, 0.356862745, 0.270588235>;
#declare farge_Dark_Cornflower_Blue = srgb <0.149019608, 0.258823529, 0.545098039>;
#declare farge_Dark_Cyan = srgb <0, 0.545098039, 0.545098039>;
#declare farge_Dark_Electric_Blue = srgb <0.325490196, 0.407843137, 0.470588235>;
#declare farge_Dark_Goldenrod = srgb <0.721568627, 0.525490196, 0.043137255>;
#declare farge_Dark_Green = srgb <0.003921569, 0.196078431, 0.125490196>;
#declare farge_Dark_Imperial_Blue = srgb <0, 0.254901961, 0.415686275>;
#declare farge_Dark_Jungle_Green = srgb <0.101960784, 0.141176471, 0.129411765>;
#declare farge_Dark_Khaki = srgb <0.741176471, 0.717647059, 0.419607843>;
#declare farge_Dark_Lava = srgb <0.282352941, 0.235294118, 0.196078431>;
#declare farge_Dark_Lavender = srgb <0.450980392, 0.309803922, 0.588235294>;
#declare farge_Dark_Liver = srgb <0.325490196, 0.294117647, 0.309803922>;
#declare farge_Dark_Liver_Horses = srgb <0.329411765, 0.239215686, 0.215686275>;
#declare farge_Dark_Magenta = srgb <0.545098039, 0, 0.545098039>;
#declare farge_Dark_Medium_Gray = srgb <0.662745098, 0.662745098, 0.662745098>;
#declare farge_Dark_Midnight_Blue = srgb <0, 0.2, 0.4>;
#declare farge_Dark_Moss_Green = srgb <0.290196078, 0.364705882, 0.137254902>;
#declare farge_Dark_Olive_Green = srgb <0.333333333, 0.419607843, 0.184313725>;
#declare farge_Dark_Orange = srgb <1, 0.549019608, 0>;
#declare farge_Dark_Orchid = srgb <0.6, 0.196078431, 0.8>;
#declare farge_Dark_Pastel_Blue = srgb <0.466666667, 0.619607843, 0.796078431>;
#declare farge_Dark_Pastel_Green = srgb <0.011764706, 0.752941176, 0.235294118>;
#declare farge_Dark_Pastel_Purple = srgb <0.588235294, 0.435294118, 0.839215686>;
#declare farge_Dark_Pastel_Red = srgb <0.760784314, 0.231372549, 0.133333333>;
#declare farge_Dark_Pink = srgb <0.905882353, 0.329411765, 0.501960784>;
#declare farge_Dark_Powder_Blue = srgb <0, 0.2, 0.6>;
#declare farge_Dark_Puce = srgb <0.309803922, 0.22745098, 0.235294118>;
#declare farge_Dark_Purple = srgb <0.188235294, 0.098039216, 0.203921569>;
#declare farge_Dark_Raspberry = srgb <0.529411765, 0.149019608, 0.341176471>;
#declare farge_Dark_Red = srgb <0.545098039, 0, 0>;
#declare farge_Dark_Salmon = srgb <0.91372549, 0.588235294, 0.478431373>;
#declare farge_Dark_Scarlet = srgb <0.337254902, 0.011764706, 0.098039216>;
#declare farge_Dark_Sea_Green = srgb <0.560784314, 0.737254902, 0.560784314>;
#declare farge_Dark_Sienna = srgb <0.235294118, 0.078431373, 0.078431373>;
#declare farge_Dark_Sky_Blue = srgb <0.549019608, 0.745098039, 0.839215686>;
#declare farge_Dark_Slate_Blue = srgb <0.282352941, 0.239215686, 0.545098039>;
#declare farge_Dark_Slate_Gray = srgb <0.184313725, 0.309803922, 0.309803922>;
#declare farge_Dark_Spring_Green = srgb <0.090196078, 0.447058824, 0.270588235>;
#declare farge_Dark_Tan = srgb <0.568627451, 0.505882353, 0.317647059>;
#declare farge_Dark_Tangerine = srgb <1, 0.658823529, 0.070588235>;
#declare farge_Dark_Taupe = srgb <0.282352941, 0.235294118, 0.196078431>;
#declare farge_Dark_Terra_Cotta = srgb <0.8, 0.305882353, 0.360784314>;
#declare farge_Dark_Turquoise = srgb <0, 0.807843137, 0.819607843>;
#declare farge_Dark_Vanilla = srgb <0.819607843, 0.745098039, 0.658823529>;
#declare farge_Dark_Violet = srgb <0.580392157, 0, 0.82745098>;
#declare farge_Dark_Yellow = srgb <0.607843137, 0.529411765, 0.047058824>;
#declare farge_Dartmouth_Green = srgb <0, 0.439215686, 0.235294118>;
#declare farge_Davys_Grey = srgb <0.333333333, 0.333333333, 0.333333333>;
#declare farge_Debian_Red = srgb <0.843137255, 0.039215686, 0.325490196>;
#declare farge_Deep_Carmine = srgb <0.662745098, 0.125490196, 0.243137255>;
#declare farge_Deep_Carmine_Pink = srgb <0.937254902, 0.188235294, 0.219607843>;
#declare farge_Deep_Carrot_Orange = srgb <0.91372549, 0.411764706, 0.17254902>;
#declare farge_Deep_Champagne = srgb <0.980392157, 0.839215686, 0.647058824>;
#declare farge_Deep_Chestnut = srgb <0.725490196, 0.305882353, 0.282352941>;
#declare farge_Deep_Coffee = srgb <0.439215686, 0.258823529, 0.254901961>;
#declare farge_Deep_Fuchsia = srgb <0.756862745, 0.329411765, 0.756862745>;
#declare farge_Deep_Green = srgb <0.019607843, 0.4, 0.031372549>;
#declare farge_Deep_Green_Cyan_Turquoise = srgb <0.054901961, 0.48627451, 0.380392157>;
#declare farge_Deep_Jungle_Green = srgb <0, 0.294117647, 0.28627451>;
#declare farge_Deep_Koamaru = srgb <0.2, 0.2, 0.4>;
#declare farge_Deep_Lemon = srgb <0.960784314, 0.780392157, 0.101960784>;
#declare farge_Deep_Lilac = srgb <0.6, 0.333333333, 0.733333333>;
#declare farge_Deep_Magenta = srgb <0.8, 0, 0.8>;
#declare farge_Deep_Mauve = srgb <0.831372549, 0.450980392, 0.831372549>;
#declare farge_Deep_Moss_Green = srgb <0.207843137, 0.368627451, 0.231372549>;
#declare farge_Deep_Peach = srgb <1, 0.796078431, 0.643137255>;
#declare farge_Deep_Pink = srgb <1, 0.078431373, 0.576470588>;
#declare farge_Deep_Puce = srgb <0.662745098, 0.360784314, 0.407843137>;
#declare farge_Deep_Ruby = srgb <0.517647059, 0.247058824, 0.356862745>;
#declare farge_Deep_Saffron = srgb <1, 0.6, 0.2>;
#declare farge_Deep_Sky_Blue = srgb <0, 0.749019608, 1>;
#declare farge_Deep_Spring_Bud = srgb <0.333333333, 0.419607843, 0.184313725>;
#declare farge_Deep_Taupe = srgb <0.494117647, 0.368627451, 0.376470588>;
#declare farge_Deep_Tuscan_Red = srgb <0.4, 0.258823529, 0.301960784>;
#declare farge_Deer = srgb <0.729411765, 0.529411765, 0.349019608>;
#declare farge_Desaturated_Cyan = srgb <0.4, 0.6, 0.6>;
#declare farge_Desert = srgb <0.756862745, 0.603921569, 0.419607843>;
#declare farge_Desire = srgb <0.917647059, 0.235294118, 0.325490196>;
#declare farge_Diamond = srgb <0.725490196, 0.949019608, 1>;
#declare farge_Dim_Gray = srgb <0.411764706, 0.411764706, 0.411764706>;
#declare farge_Dirt = srgb <0.607843137, 0.462745098, 0.325490196>;
#declare farge_Dodger_Blue = srgb <0.117647059, 0.564705882, 1>;
#declare farge_Dogwood_Rose = srgb <0.843137255, 0.094117647, 0.407843137>;
#declare farge_Dollar_Bill = srgb <0.521568627, 0.733333333, 0.396078431>;
#declare farge_Donkey_Brown = srgb <0.4, 0.298039216, 0.156862745>;
#declare farge_Drab = srgb <0.588235294, 0.443137255, 0.090196078>;
#declare farge_Duke_Blue = srgb <0, 0, 0.611764706>;
#declare farge_Dust_Storm = srgb <0.898039216, 0.8, 0.788235294>;
#declare farge_Dutch_White = srgb <0.937254902, 0.874509804, 0.733333333>;
#declare farge_Earth_Yellow = srgb <0.882352941, 0.662745098, 0.37254902>;
#declare farge_Ebony = srgb <0.333333333, 0.364705882, 0.31372549>;
#declare farge_Ecru = srgb <0.760784314, 0.698039216, 0.501960784>;
#declare farge_Eggshell = srgb <0.941176471, 0.917647059, 0.839215686>;
#declare farge_Egyptian_Blue = srgb <0.062745098, 0.203921569, 0.650980392>;
#declare farge_Electric_Blue = srgb <0.490196078, 0.976470588, 1>;
#declare farge_Electric_Crimson = srgb <1, 0, 0.247058824>;
#declare farge_Electric_Indigo = srgb <0.435294118, 0, 1>;
#declare farge_Electric_Lavender = srgb <0.956862745, 0.733333333, 1>;
#declare farge_Electric_Purple = srgb <0.749019608, 0, 1>;
#declare farge_Electric_Violet = srgb <0.560784314, 0, 1>;
#declare farge_Electric_Yellow = srgb <1, 1, 0.2>;
#declare farge_Emerald = srgb <0.31372549, 0.784313725, 0.470588235>;
#declare farge_Eminence = srgb <0.423529412, 0.188235294, 0.509803922>;
#declare farge_English_Green = srgb <0.105882353, 0.301960784, 0.243137255>;
#declare farge_English_Lavender = srgb <0.705882353, 0.51372549, 0.584313725>;
#declare farge_English_Red = srgb <0.670588235, 0.294117647, 0.321568627>;
#declare farge_English_Violet = srgb <0.337254902, 0.235294118, 0.360784314>;
#declare farge_Erin = srgb <0, 1, 0.250980392>;
#declare farge_Eton_Blue = srgb <0.588235294, 0.784313725, 0.635294118>;
#declare farge_Eucalyptus = srgb <0.266666667, 0.843137255, 0.658823529>;
#declare farge_Fallow = srgb <0.756862745, 0.603921569, 0.419607843>;
#declare farge_Falu_Red = srgb <0.501960784, 0.094117647, 0.094117647>;
#declare farge_Fandango = srgb <0.709803922, 0.2, 0.537254902>;
#declare farge_Fandango_Pink = srgb <0.870588235, 0.321568627, 0.521568627>;
#declare farge_Fashion_Fuchsia = srgb <0.956862745, 0, 0.631372549>;
#declare farge_Fawn = srgb <0.898039216, 0.666666667, 0.439215686>;
#declare farge_Feldgrau = srgb <0.301960784, 0.364705882, 0.325490196>;
#declare farge_Feldspar = srgb <0.992156863, 0.835294118, 0.694117647>;
#declare farge_Fern_Green = srgb <0.309803922, 0.474509804, 0.258823529>;
#declare farge_Ferrari_Red = srgb <1, 0.156862745, 0>;
#declare farge_Field_Drab = srgb <0.423529412, 0.329411765, 0.117647059>;
#declare farge_Fiery_Rose = srgb <1, 0.329411765, 0.439215686>;
#declare farge_Fire_Engine_Red = srgb <0.807843137, 0.125490196, 0.160784314>;
#declare farge_Fire_Opal = srgb <0.91372549, 0.360784314, 0.294117647>;
#declare farge_Firebrick = srgb <0.698039216, 0.133333333, 0.133333333>;
#declare farge_Flame = srgb <0.88627451, 0.345098039, 0.133333333>;
#declare farge_Flamingo_Pink = srgb <0.988235294, 0.556862745, 0.674509804>;
#declare farge_Flattery = srgb <0.419607843, 0.266666667, 0.137254902>;
#declare farge_Flavescent = srgb <0.968627451, 0.91372549, 0.556862745>;
#declare farge_Flax = srgb <0.933333333, 0.862745098, 0.509803922>;
#declare farge_Flickr_Blue = srgb <0, 0.388235294, 0.862745098>;
#declare farge_Flickr_Pink = srgb <0.984313725, 0, 0.505882353>;
#declare farge_Flirt = srgb <0.635294118, 0, 0.42745098>;
#declare farge_Floral_White = srgb <1, 0.980392157, 0.941176471>;
#declare farge_Fluorescent_Blue = srgb <0.082352941, 0.956862745, 0.933333333>;
#declare farge_Fluorescent_Orange = srgb <1, 0.749019608, 0>;
#declare farge_Fluorescent_Pink = srgb <1, 0.078431373, 0.576470588>;
#declare farge_Fluorescent_Yellow = srgb <0.8, 1, 0>;
#declare farge_Folly = srgb <1, 0, 0.309803922>;
#declare farge_Forest_Green_Traditional = srgb <0.003921569, 0.266666667, 0.129411765>;
#declare farge_Forest_Green_Web = srgb <0.133333333, 0.545098039, 0.133333333>;
#declare farge_French_Beige = srgb <0.650980392, 0.482352941, 0.356862745>;
#declare farge_French_Bistre = srgb <0.521568627, 0.42745098, 0.301960784>;
#declare farge_French_Blue = srgb <0, 0.447058824, 0.733333333>;
#declare farge_French_Fuchsia = srgb <0.992156863, 0.247058824, 0.57254902>;
#declare farge_French_Lilac = srgb <0.525490196, 0.376470588, 0.556862745>;
#declare farge_French_Lime = srgb <0.619607843, 0.992156863, 0.219607843>;
#declare farge_French_Mauve = srgb <0.831372549, 0.450980392, 0.831372549>;
#declare farge_French_Pink = srgb <0.992156863, 0.423529412, 0.619607843>;
#declare farge_French_Plum = srgb <0.505882353, 0.078431373, 0.325490196>;
#declare farge_French_Puce = srgb <0.305882353, 0.08627451, 0.035294118>;
#declare farge_French_Raspberry = srgb <0.780392157, 0.17254902, 0.282352941>;
#declare farge_French_Rose = srgb <0.964705882, 0.290196078, 0.541176471>;
#declare farge_French_Sky_Blue = srgb <0.466666667, 0.709803922, 0.996078431>;
#declare farge_French_Violet = srgb <0.533333333, 0.023529412, 0.807843137>;
#declare farge_French_Wine = srgb <0.674509804, 0.117647059, 0.266666667>;
#declare farge_Fresh_Air = srgb <0.650980392, 0.905882353, 1>;
#declare farge_Fuchsia_Pink = srgb <1, 0.466666667, 1>;
#declare farge_Fuchsia_Purple = srgb <0.8, 0.223529412, 0.482352941>;
#declare farge_Fuchsia_Rose = srgb <0.780392157, 0.262745098, 0.458823529>;
#declare farge_Fulvous = srgb <0.894117647, 0.517647059, 0>;
#declare farge_Fuzzy_Wuzzy = srgb <0.8, 0.4, 0.4>;
#declare farge_Gainsboro = srgb <0.862745098, 0.862745098, 0.862745098>;
#declare farge_Gamboge = srgb <0.894117647, 0.607843137, 0.058823529>;
#declare farge_Gamboge_Orange_Brown = srgb <0.6, 0.4, 0>;
#declare farge_Generic_Viridian = srgb <0, 0.498039216, 0.4>;
#declare farge_Ghost_White = srgb <0.97254902, 0.97254902, 1>;
#declare farge_Giants_Orange = srgb <0.996078431, 0.352941176, 0.11372549>;
#declare farge_Ginger = srgb <0.690196078, 0.396078431, 0>;
#declare farge_Glaucous = srgb <0.376470588, 0.509803922, 0.71372549>;
#declare farge_Glitter = srgb <0.901960784, 0.909803922, 0.980392157>;
#declare farge_Go_Green = srgb <0, 0.670588235, 0.4>;
#declare farge_Gold = srgb <0.647058824, 0.48627451, 0>;
#declare farge_Gold_Metallic = srgb <0.831372549, 0.68627451, 0.215686275>;
#declare farge_Gold_Web_Golden = srgb <1, 0.843137255, 0>;
#declare farge_Golden_Brown = srgb <0.6, 0.396078431, 0.082352941>;
#declare farge_Golden_Poppy = srgb <0.988235294, 0.760784314, 0>;
#declare farge_Golden_Yellow = srgb <1, 0.874509804, 0>;
#declare farge_Goldenrod = srgb <0.854901961, 0.647058824, 0.125490196>;
#declare farge_Granny_Smith_Apple = srgb <0.658823529, 0.894117647, 0.62745098>;
#declare farge_Grape = srgb <0.435294118, 0.176470588, 0.658823529>;
#declare farge_Gray_Asparagus = srgb <0.274509804, 0.349019608, 0.270588235>;
#declare farge_Gray_Blue = srgb <0.549019608, 0.57254902, 0.674509804>;
#declare farge_Gray_Web = srgb <0.501960784, 0.501960784, 0.501960784>;
#declare farge_Green_Blue = srgb <0.066666667, 0.392156863, 0.705882353>;
#declare farge_Green_Cyan = srgb <0, 0.6, 0.4>;
#declare farge_Green_Munsell = srgb <0, 0.658823529, 0.466666667>;
#declare farge_Green_NCS = srgb <0, 0.623529412, 0.419607843>;
#declare farge_Green_Pantone = srgb <0, 0.678431373, 0.262745098>;
#declare farge_Green_Pigment = srgb <0, 0.647058824, 0.31372549>;
#declare farge_Green_RYB = srgb <0.4, 0.690196078, 0.196078431>;
#declare farge_Green_Web = srgb <0, 0.501960784, 0>;
#declare farge_Green_Yellow = srgb <0.678431373, 1, 0.184313725>;
#declare farge_Grizzly = srgb <0.533333333, 0.345098039, 0.094117647>;
#declare farge_Grullo = srgb <0.662745098, 0.603921569, 0.525490196>;
#declare farge_Gunmetal = srgb <0.164705882, 0.203921569, 0.223529412>;
#declare farge_Guppie_Green = srgb <0, 1, 0.498039216>;
#declare farge_Halaya_Ube = srgb <0.4, 0.219607843, 0.329411765>;
#declare farge_Han_Blue = srgb <0.266666667, 0.423529412, 0.811764706>;
#declare farge_Han_Purple = srgb <0.321568627, 0.094117647, 0.980392157>;
#declare farge_Hansa_Yellow = srgb <0.91372549, 0.839215686, 0.419607843>;
#declare farge_Harlequin = srgb <0.247058824, 1, 0>;
#declare farge_Harlequin_Green = srgb <0.274509804, 0.796078431, 0.094117647>;
#declare farge_Harvard_Crimson = srgb <0.788235294, 0, 0.08627451>;
#declare farge_Harvest_Gold = srgb <0.854901961, 0.568627451, 0>;
#declare farge_Heart_Gold = srgb <0.501960784, 0.501960784, 0>;
#declare farge_Heat_Wave = srgb <1, 0.478431373, 0>;
#declare farge_Heliotrope = srgb <0.874509804, 0.450980392, 1>;
#declare farge_Heliotrope_Gray = srgb <0.666666667, 0.596078431, 0.662745098>;
#declare farge_Heliotrope_Magenta = srgb <0.666666667, 0, 0.733333333>;
#declare farge_Hollywood_Cerise = srgb <0.956862745, 0, 0.631372549>;
#declare farge_Honeydew = srgb <0.941176471, 1, 0.941176471>;
#declare farge_Honolulu_Blue = srgb <0, 0.42745098, 0.690196078>;
#declare farge_Hookers_Green = srgb <0.28627451, 0.474509804, 0.419607843>;
#declare farge_Hot_Magenta = srgb <1, 0.11372549, 0.807843137>;
#declare farge_Hot_Pink = srgb <1, 0.411764706, 0.705882353>;
#declare farge_Hunter_Green = srgb <0.207843137, 0.368627451, 0.231372549>;
#declare farge_Iceberg = srgb <0.443137255, 0.650980392, 0.823529412>;
#declare farge_Icterine = srgb <0.988235294, 0.968627451, 0.368627451>;
#declare farge_Imperial = srgb <0.376470588, 0.184313725, 0.419607843>;
#declare farge_Imperial_Blue = srgb <0, 0.137254902, 0.584313725>;
#declare farge_Imperial_Purple = srgb <0.4, 0.007843137, 0.235294118>;
#declare farge_Imperial_Red = srgb <0.929411765, 0.160784314, 0.223529412>;
#declare farge_Inchworm = srgb <0.698039216, 0.925490196, 0.364705882>;
#declare farge_Independence = srgb <0.298039216, 0.317647059, 0.42745098>;
#declare farge_India_Green = srgb <0.074509804, 0.533333333, 0.031372549>;
#declare farge_Indian_Red = srgb <0.803921569, 0.360784314, 0.360784314>;
#declare farge_Indian_Yellow = srgb <0.890196078, 0.658823529, 0.341176471>;
#declare farge_Indigo = srgb <0.294117647, 0, 0.509803922>;
#declare farge_Indigo_Dye = srgb <0, 0.254901961, 0.415686275>;
#declare farge_Indigo_Web = srgb <0.294117647, 0, 0.509803922>;
#declare farge_International_Klein_Blue = srgb <0, 0.184313725, 0.654901961>;
#declare farge_International_Orange_Aerospace = srgb <1, 0.309803922, 0>;
#declare farge_International_Orange_Engineering = srgb <0.729411765, 0.08627451, 0.047058824>;
#declare farge_International_Orange_Golden_Gate_Bridge = srgb <0.752941176, 0.211764706, 0.17254902>;
#declare farge_Iris = srgb <0.352941176, 0.309803922, 0.811764706>;
#declare farge_Irresistible = srgb <0.701960784, 0.266666667, 0.423529412>;
#declare farge_Isabelline = srgb <0.956862745, 0.941176471, 0.925490196>;
#declare farge_Islamic_Green = srgb <0, 0.564705882, 0>;
#declare farge_Italian_Sky_Blue = srgb <0.698039216, 1, 1>;
#declare farge_Ivory = srgb <1, 1, 0.941176471>;
#declare farge_Jade = srgb <0, 0.658823529, 0.419607843>;
#declare farge_Japanese_Carmine = srgb <0.615686275, 0.160784314, 0.2>;
#declare farge_Japanese_Indigo = srgb <0.149019608, 0.262745098, 0.282352941>;
#declare farge_Japanese_Violet = srgb <0.356862745, 0.196078431, 0.337254902>;
#declare farge_Jasmine = srgb <0.97254902, 0.870588235, 0.494117647>;
#declare farge_Jasper = srgb <0.843137255, 0.231372549, 0.243137255>;
#declare farge_Jawad_Chicken_Color = srgb <0.764705882, 0.690196078, 0.568627451>;
#declare farge_Jelly_Bean = srgb <0.854901961, 0.380392157, 0.305882353>;
#declare farge_Jet = srgb <0.203921569, 0.203921569, 0.203921569>;
#declare farge_Jonquil = srgb <0.956862745, 0.792156863, 0.08627451>;
#declare farge_Jordy_Blue = srgb <0.541176471, 0.725490196, 0.945098039>;
#declare farge_June_Bud = srgb <0.741176471, 0.854901961, 0.341176471>;
#declare farge_Kelly_Green = srgb <0.298039216, 0.733333333, 0.090196078>;
#declare farge_Kenyan_Copper = srgb <0.48627451, 0.109803922, 0.019607843>;
#declare farge_Keppel = srgb <0.22745098, 0.690196078, 0.619607843>;
#declare farge_Khaki_Web = srgb <0.764705882, 0.690196078, 0.568627451>;
#declare farge_Kobe = srgb <0.533333333, 0.176470588, 0.090196078>;
#declare farge_Kobi = srgb <0.905882353, 0.623529412, 0.768627451>;
#declare farge_Kobicha = srgb <0.419607843, 0.266666667, 0.137254902>;
#declare farge_Kombu_Green = srgb <0.207843137, 0.258823529, 0.188235294>;
#declare farge_Ksu_Purple = srgb <0.317647059, 0.156862745, 0.533333333>;
#declare farge_KU_Crimson = srgb <0.909803922, 0, 0.050980392>;
#declare farge_La_Salle_Green = srgb <0.031372549, 0.470588235, 0.188235294>;
#declare farge_Languid_Lavender = srgb <0.839215686, 0.792156863, 0.866666667>;
#declare farge_Lapis_Lazuli = srgb <0.149019608, 0.380392157, 0.611764706>;
#declare farge_Laurel_Green = srgb <0.662745098, 0.729411765, 0.615686275>;
#declare farge_Lava = srgb <0.811764706, 0.062745098, 0.125490196>;
#declare farge_Lavender_Blue = srgb <0.8, 0.8, 1>;
#declare farge_Lavender_Blush = srgb <1, 0.941176471, 0.960784314>;
#declare farge_Lavender_Floral = srgb <0.709803922, 0.494117647, 0.862745098>;
#declare farge_Lavender_Gray = srgb <0.768627451, 0.764705882, 0.815686275>;
#declare farge_Lavender_Indigo = srgb <0.580392157, 0.341176471, 0.921568627>;
#declare farge_Lavender_Magenta = srgb <0.933333333, 0.509803922, 0.933333333>;
#declare farge_Lavender_Mist = srgb <0.901960784, 0.901960784, 0.980392157>;
#declare farge_Lavender_Pink = srgb <0.984313725, 0.682352941, 0.823529412>;
#declare farge_Lavender_Purple = srgb <0.588235294, 0.482352941, 0.71372549>;
#declare farge_Lavender_Rose = srgb <0.984313725, 0.62745098, 0.890196078>;
#declare farge_Lavender_Web = srgb <0.901960784, 0.901960784, 0.980392157>;
#declare farge_Lawn_Green = srgb <0.48627451, 0.988235294, 0>;
#declare farge_Lemon = srgb <1, 0.968627451, 0>;
#declare farge_Lemon_Chiffon = srgb <1, 0.980392157, 0.803921569>;
#declare farge_Lemon_Curry = srgb <0.8, 0.62745098, 0.11372549>;
#declare farge_Lemon_Glacier = srgb <0.992156863, 1, 0>;
#declare farge_Lemon_Lime = srgb <0.890196078, 1, 0>;
#declare farge_Lemon_Meringue = srgb <0.964705882, 0.917647059, 0.745098039>;
#declare farge_Lemon_Yellow = srgb <1, 0.956862745, 0.309803922>;
#declare farge_Lenurple = srgb <0.729411765, 0.576470588, 0.847058824>;
#declare farge_Liberty = srgb <0.329411765, 0.352941176, 0.654901961>;
#declare farge_Licorice = srgb <0.101960784, 0.066666667, 0.062745098>;
#declare farge_Light_Apricot = srgb <0.992156863, 0.835294118, 0.694117647>;
#declare farge_Light_Blue = srgb <0.678431373, 0.847058824, 0.901960784>;
#declare farge_Light_Brown = srgb <0.709803922, 0.396078431, 0.11372549>;
#declare farge_Light_Carmine_Pink = srgb <0.901960784, 0.403921569, 0.443137255>;
#declare farge_Light_Coral = srgb <0.941176471, 0.501960784, 0.501960784>;
#declare farge_Light_Cornflower_Blue = srgb <0.576470588, 0.8, 0.917647059>;
#declare farge_Light_Crimson = srgb <0.960784314, 0.411764706, 0.568627451>;
#declare farge_Light_Cyan = srgb <0.878431373, 1, 1>;
#declare farge_Light_Deep_Pink = srgb <1, 0.360784314, 0.803921569>;
#declare farge_Light_French_Beige = srgb <0.784313725, 0.678431373, 0.498039216>;
#declare farge_Light_Fuchsia_Pink = srgb <0.976470588, 0.517647059, 0.937254902>;
#declare farge_Light_Goldenrod_Yellow = srgb <0.980392157, 0.980392157, 0.823529412>;
#declare farge_Light_Gray = srgb <0.82745098, 0.82745098, 0.82745098>;
#declare farge_Light_Grayish_Magenta = srgb <0.8, 0.6, 0.8>;
#declare farge_Light_Green = srgb <0.564705882, 0.933333333, 0.564705882>;
#declare farge_Light_Hot_Pink = srgb <1, 0.701960784, 0.870588235>;
#declare farge_Light_Khaki = srgb <0.941176471, 0.901960784, 0.549019608>;
#declare farge_Light_Medium_Orchid = srgb <0.82745098, 0.607843137, 0.796078431>;
#declare farge_Light_Moss_Green = srgb <0.678431373, 0.874509804, 0.678431373>;
#declare farge_Light_Orange = srgb <0.996078431, 0.847058824, 0.694117647>;
#declare farge_Light_Orchid = srgb <0.901960784, 0.658823529, 0.843137255>;
#declare farge_Light_Pastel_Purple = srgb <0.694117647, 0.611764706, 0.850980392>;
#declare farge_Light_Periwinkle = srgb <0.77254902, 0.796078431, 0.882352941>;
#declare farge_Light_Pink = srgb <1, 0.71372549, 0.756862745>;
#declare farge_Light_Red_Ochre = srgb <0.91372549, 0.454901961, 0.317647059>;
#declare farge_Light_Salmon = srgb <1, 0.62745098, 0.478431373>;
#declare farge_Light_Salmon_Pink = srgb <1, 0.6, 0.6>;
#declare farge_Light_Sea_Green = srgb <0.125490196, 0.698039216, 0.666666667>;
#declare farge_Light_Sky_Blue = srgb <0.529411765, 0.807843137, 0.980392157>;
#declare farge_Light_Slate_Gray = srgb <0.466666667, 0.533333333, 0.6>;
#declare farge_Light_Steel_Blue = srgb <0.690196078, 0.768627451, 0.870588235>;
#declare farge_Light_Taupe = srgb <0.701960784, 0.545098039, 0.42745098>;
#declare farge_Light_Thulian_Pink = srgb <0.901960784, 0.560784314, 0.674509804>;
#declare farge_Light_Yellow = srgb <1, 1, 0.878431373>;
#declare farge_Lilac = srgb <0.784313725, 0.635294118, 0.784313725>;
#declare farge_Lime_Green = srgb <0.196078431, 0.803921569, 0.196078431>;
#declare farge_Limerick = srgb <0.615686275, 0.760784314, 0.035294118>;
#declare farge_Lincoln_Green = srgb <0.098039216, 0.349019608, 0.019607843>;
#declare farge_Linen = srgb <0.980392157, 0.941176471, 0.901960784>;
#declare farge_Lion = srgb <0.756862745, 0.603921569, 0.419607843>;
#declare farge_Liseran_Purple = srgb <0.870588235, 0.435294118, 0.631372549>;
#declare farge_Little_Boy_Blue = srgb <0.423529412, 0.62745098, 0.862745098>;
#declare farge_Liver = srgb <0.403921569, 0.298039216, 0.278431373>;
#declare farge_Liver_Chestnut = srgb <0.596078431, 0.454901961, 0.337254902>;
#declare farge_Liver_Dogs = srgb <0.721568627, 0.42745098, 0.160784314>;
#declare farge_Liver_Organ = srgb <0.423529412, 0.180392157, 0.121568627>;
#declare farge_Livid = srgb <0.4, 0.6, 0.8>;
#declare farge_Lumber = srgb <1, 0.894117647, 0.803921569>;
#declare farge_Lust = srgb <0.901960784, 0.125490196, 0.125490196>;
#declare farge_Macaroni_And_Cheese = srgb <1, 0.741176471, 0.533333333>;
#declare farge_Magenta_Dye = srgb <0.792156863, 0.121568627, 0.482352941>;
#declare farge_Magenta_Haze = srgb <0.623529412, 0.270588235, 0.462745098>;
#declare farge_Magenta_Pantone = srgb <0.815686275, 0.254901961, 0.494117647>;
#declare farge_Magenta_Pink = srgb <0.8, 0.2, 0.545098039>;
#declare farge_Magenta_Process = srgb <1, 0, 0.564705882>;
#declare farge_Magic_Mint = srgb <0.666666667, 0.941176471, 0.819607843>;
#declare farge_Magnolia = srgb <0.97254902, 0.956862745, 1>;
#declare farge_Mahogany = srgb <0.752941176, 0.250980392, 0>;
#declare farge_Maize = srgb <0.984313725, 0.925490196, 0.364705882>;
#declare farge_Majorelle_Blue = srgb <0.376470588, 0.31372549, 0.862745098>;
#declare farge_Malachite = srgb <0.043137255, 0.854901961, 0.317647059>;
#declare farge_Manatee = srgb <0.592156863, 0.603921569, 0.666666667>;
#declare farge_Mango = srgb <0.992156863, 0.745098039, 0.007843137>;
#declare farge_Mango_Tango = srgb <1, 0.509803922, 0.262745098>;
#declare farge_Mantis = srgb <0.454901961, 0.764705882, 0.396078431>;
#declare farge_Mardi_Gras = srgb <0.533333333, 0, 0.521568627>;
#declare farge_Marigold = srgb <0.917647059, 0.635294118, 0.129411765>;
#declare farge_Maroon_Web = srgb <0.501960784, 0, 0>;
#declare farge_Mauve = srgb <0.878431373, 0.690196078, 1>;
#declare farge_Mauve_Taupe = srgb <0.568627451, 0.37254902, 0.42745098>;
#declare farge_Mauvelous = srgb <0.937254902, 0.596078431, 0.666666667>;
#declare farge_May_Green = srgb <0.298039216, 0.568627451, 0.254901961>;
#declare farge_Maya_Blue = srgb <0.450980392, 0.760784314, 0.984313725>;
#declare farge_Meat_Brown = srgb <0.898039216, 0.717647059, 0.231372549>;
#declare farge_Medium_Aquamarine = srgb <0.4, 0.866666667, 0.666666667>;
#declare farge_Medium_Blue = srgb <0, 0, 0.803921569>;
#declare farge_Medium_Candy_Apple_Red = srgb <0.88627451, 0.023529412, 0.17254902>;
#declare farge_Medium_Carmine = srgb <0.68627451, 0.250980392, 0.207843137>;
#declare farge_Medium_Champagne = srgb <0.952941176, 0.898039216, 0.670588235>;
#declare farge_Medium_Electric_Blue = srgb <0.011764706, 0.31372549, 0.588235294>;
#declare farge_Medium_Jungle_Green = srgb <0.109803922, 0.207843137, 0.176470588>;
#declare farge_Medium_Lavender_Magenta = srgb <0.866666667, 0.62745098, 0.866666667>;
#declare farge_Medium_Orchid = srgb <0.729411765, 0.333333333, 0.82745098>;
#declare farge_Medium_Persian_Blue = srgb <0, 0.403921569, 0.647058824>;
#declare farge_Medium_Purple = srgb <0.576470588, 0.439215686, 0.858823529>;
#declare farge_Medium_Red_Violet = srgb <0.733333333, 0.2, 0.521568627>;
#declare farge_Medium_Ruby = srgb <0.666666667, 0.250980392, 0.411764706>;
#declare farge_Medium_Sea_Green = srgb <0.235294118, 0.701960784, 0.443137255>;
#declare farge_Medium_Sky_Blue = srgb <0.501960784, 0.854901961, 0.921568627>;
#declare farge_Medium_Slate_Blue = srgb <0.482352941, 0.407843137, 0.933333333>;
#declare farge_Medium_Spring_Bud = srgb <0.788235294, 0.862745098, 0.529411765>;
#declare farge_Medium_Spring_Green = srgb <0, 0.980392157, 0.603921569>;
#declare farge_Medium_Taupe = srgb <0.403921569, 0.298039216, 0.278431373>;
#declare farge_Medium_Turquoise = srgb <0.282352941, 0.819607843, 0.8>;
#declare farge_Medium_Tuscan_Red = srgb <0.474509804, 0.266666667, 0.231372549>;
#declare farge_Medium_Vermilion = srgb <0.850980392, 0.376470588, 0.231372549>;
#declare farge_Medium_Violet_Red = srgb <0.780392157, 0.082352941, 0.521568627>;
#declare farge_Mellow_Apricot = srgb <0.97254902, 0.721568627, 0.470588235>;
#declare farge_Mellow_Yellow = srgb <0.97254902, 0.870588235, 0.494117647>;
#declare farge_Metallic_Gold = srgb <0.82745098, 0.68627451, 0.215686275>;
#declare farge_Metallic_Sunburst = srgb <0.611764706, 0.48627451, 0.219607843>;
#declare farge_Mexican_Pink = srgb <0.894117647, 0, 0.48627451>;
#declare farge_Middle_Yellow_Red = srgb <0.925490196, 0.694117647, 0.462745098>;
#declare farge_Midnight_Blue = srgb <0.098039216, 0.098039216, 0.439215686>;
#declare farge_Midnight_Green_Eagle_Green = srgb <0, 0.28627451, 0.325490196>;
#declare farge_Mikado_Yellow = srgb <1, 0.768627451, 0.047058824>;
#declare farge_Mimi_Pink = srgb <1, 0.854901961, 0.91372549>;
#declare farge_Mindaro = srgb <0.890196078, 0.976470588, 0.533333333>;
#declare farge_Ming = srgb <0.211764706, 0.454901961, 0.490196078>;
#declare farge_Minion_Yellow = srgb <0.960784314, 0.878431373, 0.31372549>;
#declare farge_Mint = srgb <0.243137255, 0.705882353, 0.537254902>;
#declare farge_Mint_Cream = srgb <0.960784314, 1, 0.980392157>;
#declare farge_Mint_Green = srgb <0.596078431, 1, 0.596078431>;
#declare farge_Misty_Rose = srgb <1, 0.894117647, 0.882352941>;
#declare farge_Moccasin = srgb <0.980392157, 0.921568627, 0.843137255>;
#declare farge_Mode_Beige = srgb <0.588235294, 0.443137255, 0.090196078>;
#declare farge_Moonstone_Blue = srgb <0.450980392, 0.662745098, 0.760784314>;
#declare farge_Mordant_Red_19 = srgb <0.682352941, 0.047058824, 0>;
#declare farge_Morning_Blue = srgb <0.552941176, 0.639215686, 0.6>;
#declare farge_Moss_Green = srgb <0.541176471, 0.603921569, 0.356862745>;
#declare farge_Mountain_Meadow = srgb <0.188235294, 0.729411765, 0.560784314>;
#declare farge_Mountbatten_Pink = srgb <0.6, 0.478431373, 0.552941176>;
#declare farge_Msu_Green = srgb <0.094117647, 0.270588235, 0.231372549>;
#declare farge_Mughal_Green = srgb <0.188235294, 0.376470588, 0.188235294>;
#declare farge_Mulberry = srgb <0.77254902, 0.294117647, 0.549019608>;
#declare farge_Mustard = srgb <1, 0.858823529, 0.345098039>;
#declare farge_Myrtle_Green = srgb <0.192156863, 0.470588235, 0.450980392>;
#declare farge_Nadeshiko_Pink = srgb <0.964705882, 0.678431373, 0.776470588>;
#declare farge_Napier_Green = srgb <0.164705882, 0.501960784, 0>;
#declare farge_Naples_Yellow = srgb <0.980392157, 0.854901961, 0.368627451>;
#declare farge_Navajo_White = srgb <1, 0.870588235, 0.678431373>;
#declare farge_Navy_Blue = srgb <0, 0, 0.501960784>;
#declare farge_Navy_Purple = srgb <0.580392157, 0.341176471, 0.921568627>;
#declare farge_Neon_Blue = srgb <0.274509804, 0.4, 1>;
#declare farge_Neon_Carrot = srgb <1, 0.639215686, 0.262745098>;
#declare farge_Neon_Fuchsia = srgb <0.996078431, 0.254901961, 0.392156863>;
#declare farge_Neon_Green = srgb <0.223529412, 1, 0.078431373>;
#declare farge_New_Car = srgb <0.129411765, 0.309803922, 0.776470588>;
#declare farge_New_York_Pink = srgb <0.843137255, 0.51372549, 0.498039216>;
#declare farge_Nickel = srgb <0.447058824, 0.454901961, 0.447058824>;
#declare farge_Non_Photo_Blue = srgb <0.643137255, 0.866666667, 0.929411765>;
#declare farge_North_Texas_Green = srgb <0.019607843, 0.564705882, 0.2>;
#declare farge_Nyanza = srgb <0.91372549, 1, 0.858823529>;
#declare farge_Ocean_Boat_Blue = srgb <0, 0.466666667, 0.745098039>;
#declare farge_Ochre = srgb <0.8, 0.466666667, 0.133333333>;
#declare farge_Office_Green = srgb <0, 0.501960784, 0>;
#declare farge_Old_Burgundy = srgb <0.262745098, 0.188235294, 0.180392157>;
#declare farge_Old_Gold = srgb <0.811764706, 0.709803922, 0.231372549>;
#declare farge_Old_Heliotrope = srgb <0.337254902, 0.235294118, 0.360784314>;
#declare farge_Old_Lace = srgb <0.992156863, 0.960784314, 0.901960784>;
#declare farge_Old_Lavender = srgb <0.474509804, 0.407843137, 0.470588235>;
#declare farge_Old_Mauve = srgb <0.403921569, 0.192156863, 0.278431373>;
#declare farge_Old_Moss_Green = srgb <0.525490196, 0.494117647, 0.211764706>;
#declare farge_Old_Rose = srgb <0.752941176, 0.501960784, 0.505882353>;
#declare farge_Old_Silver = srgb <0.517647059, 0.517647059, 0.509803922>;
#declare farge_Olive = srgb <0.501960784, 0.501960784, 0>;
#declare farge_Olive_Drab_No3 = srgb <0.419607843, 0.556862745, 0.137254902>;
#declare farge_Olive_Drab_No7 = srgb <0.235294118, 0.203921569, 0.121568627>;
#declare farge_Olivine = srgb <0.603921569, 0.725490196, 0.450980392>;
#declare farge_Opal = srgb <0.658823529, 0.764705882, 0.737254902>;
#declare farge_Opera_Mauve = srgb <0.717647059, 0.517647059, 0.654901961>;
#declare farge_Orange_Pantone = srgb <1, 0.345098039, 0>;
#declare farge_Orange_Peel = srgb <1, 0.623529412, 0>;
#declare farge_Orange_Red = srgb <1, 0.407843137, 0.121568627>;
#declare farge_Orange_RYB = srgb <0.984313725, 0.6, 0.007843137>;
#declare farge_Orange_Web = srgb <1, 0.647058824, 0>;
#declare farge_Orange_Yellow = srgb <0.960784314, 0.741176471, 0.121568627>;
#declare farge_Orchid = srgb <0.854901961, 0.439215686, 0.839215686>;
#declare farge_Orchid_Pink = srgb <0.949019608, 0.741176471, 0.803921569>;
#declare farge_Orioles_Orange = srgb <0.984313725, 0.309803922, 0.078431373>;
#declare farge_Otter_Brown = srgb <0.396078431, 0.262745098, 0.129411765>;
#declare farge_OU_Crimson_red = srgb <0.517647059, 0.08627451, 0.090196078>;
#declare farge_Outer_Space = srgb <0.254901961, 0.290196078, 0.298039216>;
#declare farge_Outrageous_Orange = srgb <1, 0.431372549, 0.290196078>;
#declare farge_Oxblood = srgb <0.501960784, 0, 0.125490196>;
#declare farge_Oxford_Blue = srgb <0, 0.129411765, 0.278431373>;
#declare farge_Pacific_Blue = srgb <0.109803922, 0.662745098, 0.788235294>;
#declare farge_Pakistan_Green = srgb <0, 0.4, 0>;
#declare farge_Palatinate_Blue = srgb <0.152941176, 0.231372549, 0.88627451>;
#declare farge_Palatinate_Purple = srgb <0.407843137, 0.156862745, 0.376470588>;
#declare farge_Pale_Aqua = srgb <0.737254902, 0.831372549, 0.901960784>;
#declare farge_Pale_Blue = srgb <0.68627451, 0.933333333, 0.933333333>;
#declare farge_Pale_Brown = srgb <0.596078431, 0.462745098, 0.329411765>;
#declare farge_Pale_Carmine = srgb <0.68627451, 0.250980392, 0.207843137>;
#declare farge_Pale_Cerulean = srgb <0.607843137, 0.768627451, 0.88627451>;
#declare farge_Pale_Chestnut = srgb <0.866666667, 0.678431373, 0.68627451>;
#declare farge_Pale_Copper = srgb <0.854901961, 0.541176471, 0.403921569>;
#declare farge_Pale_Cornflower_Blue = srgb <0.670588235, 0.803921569, 0.937254902>;
#declare farge_Pale_Gold = srgb <0.901960784, 0.745098039, 0.541176471>;
#declare farge_Pale_Goldenrod = srgb <0.933333333, 0.909803922, 0.666666667>;
#declare farge_Pale_Green = srgb <0.596078431, 0.984313725, 0.596078431>;
#declare farge_Pale_Lavender = srgb <0.862745098, 0.815686275, 1>;
#declare farge_Pale_Magenta = srgb <0.976470588, 0.517647059, 0.898039216>;
#declare farge_Pale_Pink = srgb <0.980392157, 0.854901961, 0.866666667>;
#declare farge_Pale_Plum = srgb <0.866666667, 0.62745098, 0.866666667>;
#declare farge_Pale_Purple_Pantone = srgb <0.980392157, 0.901960784, 0.980392157>;
#declare farge_Pale_Robin_Egg_Blue = srgb <0.588235294, 0.870588235, 0.819607843>;
#declare farge_Pale_Silver = srgb <0.788235294, 0.752941176, 0.733333333>;
#declare farge_Pale_Spring_Bud = srgb <0.925490196, 0.921568627, 0.741176471>;
#declare farge_Pale_Taupe = srgb <0.737254902, 0.596078431, 0.494117647>;
#declare farge_Pale_Turquoise = srgb <0.68627451, 0.933333333, 0.933333333>;
#declare farge_Pale_Violet = srgb <0.8, 0.6, 1>;
#declare farge_Pale_Violet_Red = srgb <0.858823529, 0.439215686, 0.576470588>;
#declare farge_Pansy_Purple = srgb <0.470588235, 0.094117647, 0.290196078>;
#declare farge_Paolo_Veronese_Green = srgb <0, 0.607843137, 0.490196078>;
#declare farge_Papaya_Whip = srgb <1, 0.937254902, 0.835294118>;
#declare farge_Paradise_Pink = srgb <0.901960784, 0.243137255, 0.384313725>;
#declare farge_Paris_Green = srgb <0.31372549, 0.784313725, 0.470588235>;
#declare farge_Pastel_Blue = srgb <0.682352941, 0.776470588, 0.811764706>;
#declare farge_Pastel_Brown = srgb <0.51372549, 0.411764706, 0.325490196>;
#declare farge_Pastel_Gray = srgb <0.811764706, 0.811764706, 0.768627451>;
#declare farge_Pastel_Green = srgb <0.466666667, 0.866666667, 0.466666667>;
#declare farge_Pastel_Magenta = srgb <0.956862745, 0.603921569, 0.760784314>;
#declare farge_Pastel_Orange = srgb <1, 0.701960784, 0.278431373>;
#declare farge_Pastel_Pink = srgb <0.870588235, 0.647058824, 0.643137255>;
#declare farge_Pastel_Purple = srgb <0.701960784, 0.619607843, 0.709803922>;
#declare farge_Pastel_Red = srgb <1, 0.411764706, 0.380392157>;
#declare farge_Pastel_Violet = srgb <0.796078431, 0.6, 0.788235294>;
#declare farge_Pastel_Yellow = srgb <0.992156863, 0.992156863, 0.588235294>;
#declare farge_Patriarch = srgb <0.501960784, 0, 0.501960784>;
#declare farge_Paynes_Grey = srgb <0.325490196, 0.407843137, 0.470588235>;
#declare farge_Peach = srgb <1, 0.898039216, 0.705882353>;
#declare farge_Peach_Orange = srgb <1, 0.8, 0.6>;
#declare farge_Peach_Puff = srgb <1, 0.854901961, 0.725490196>;
#declare farge_Peach_Yellow = srgb <0.980392157, 0.874509804, 0.678431373>;
#declare farge_Pear = srgb <0.819607843, 0.88627451, 0.192156863>;
#declare farge_Pearl = srgb <0.917647059, 0.878431373, 0.784313725>;
#declare farge_Pearl_Aqua = srgb <0.533333333, 0.847058824, 0.752941176>;
#declare farge_Peridot = srgb <0.901960784, 0.88627451, 0>;
#declare farge_Periwinkle = srgb <0.8, 0.8, 1>;
#declare farge_Persian_Blue = srgb <0.109803922, 0.223529412, 0.733333333>;
#declare farge_Persian_Green = srgb <0, 0.650980392, 0.576470588>;
#declare farge_Persian_Indigo = srgb <0.196078431, 0.070588235, 0.478431373>;
#declare farge_Persian_Orange = srgb <0.850980392, 0.564705882, 0.345098039>;
#declare farge_Persian_Pink = srgb <0.968627451, 0.498039216, 0.745098039>;
#declare farge_Persian_Plum = srgb <0.439215686, 0.109803922, 0.109803922>;
#declare farge_Persian_Red = srgb <0.8, 0.2, 0.2>;
#declare farge_Persian_Rose = srgb <0.996078431, 0.156862745, 0.635294118>;
#declare farge_Persimmon = srgb <0.925490196, 0.345098039, 0>;
#declare farge_Peru = srgb <0.803921569, 0.521568627, 0.247058824>;
#declare farge_Phlox = srgb <0.874509804, 0, 1>;
#declare farge_Phthalo_Blue = srgb <0, 0.058823529, 0.537254902>;
#declare farge_Phthalo_Green = srgb <0.070588235, 0.207843137, 0.141176471>;
#declare farge_Picotee_Blue = srgb <0.180392157, 0.152941176, 0.529411765>;
#declare farge_Picton_Blue = srgb <0.270588235, 0.694117647, 0.909803922>;
#declare farge_Pictorial_Carmine = srgb <0.764705882, 0.043137255, 0.305882353>;
#declare farge_Piggy_Pink = srgb <0.992156863, 0.866666667, 0.901960784>;
#declare farge_Pine_Green = srgb <0.003921569, 0.474509804, 0.435294118>;
#declare farge_Pine_Tree = srgb <0.164705882, 0.184313725, 0.137254902>;
#declare farge_Pineapple = srgb <0.337254902, 0.235294118, 0.360784314>;
#declare farge_Pink = srgb <1, 0.752941176, 0.796078431>;
#declare farge_Pink_Lace = srgb <1, 0.866666667, 0.956862745>;
#declare farge_Pink_Lavender = srgb <0.847058824, 0.698039216, 0.819607843>;
#declare farge_Pink_Orange = srgb <1, 0.6, 0.4>;
#declare farge_Pink_Pantone = srgb <0.843137255, 0.282352941, 0.580392157>;
#declare farge_Pink_Pearl = srgb <0.905882353, 0.674509804, 0.811764706>;
#declare farge_Pink_Sherbet = srgb <0.968627451, 0.560784314, 0.654901961>;
#declare farge_Pistachio = srgb <0.576470588, 0.77254902, 0.447058824>;
#declare farge_Platinum = srgb <0.898039216, 0.894117647, 0.88627451>;
#declare farge_Plum = srgb <0.556862745, 0.270588235, 0.521568627>;
#declare farge_Plum_Web = srgb <0.866666667, 0.62745098, 0.866666667>;
#declare farge_Pomp_And_Power = srgb <0.525490196, 0.376470588, 0.556862745>;
#declare farge_Popstar = srgb <0.745098039, 0.309803922, 0.384313725>;
#declare farge_Portland_Orange = srgb <1, 0.352941176, 0.211764706>;
#declare farge_Powder_Blue = srgb <0.690196078, 0.878431373, 0.901960784>;
#declare farge_Princeton_Orange = srgb <0.960784314, 0.501960784, 0.145098039>;
#declare farge_Prune = srgb <0.439215686, 0.109803922, 0.109803922>;
#declare farge_Prussian_Blue = srgb <0, 0.192156863, 0.325490196>;
#declare farge_Psychedelic_Purple = srgb <0.874509804, 0, 1>;
#declare farge_Puce = srgb <0.8, 0.533333333, 0.6>;
#declare farge_Puce_Red = srgb <0.447058824, 0.184313725, 0.215686275>;
#declare farge_Pullman_Brown_UPS_Brown = srgb <0.392156863, 0.254901961, 0.090196078>;
#declare farge_Pullman_Green = srgb <0.231372549, 0.2, 0.109803922>;
#declare farge_Pumpkin = srgb <1, 0.458823529, 0.094117647>;
#declare farge_Purple = srgb <0.415686275, 0.050980392, 0.678431373>;
#declare farge_Purple_Heart = srgb <0.411764706, 0.207843137, 0.611764706>;
#declare farge_Purple_Mountain_Majesty = srgb <0.588235294, 0.470588235, 0.71372549>;
#declare farge_Purple_Munsell = srgb <0.623529412, 0, 0.77254902>;
#declare farge_Purple_Navy = srgb <0.305882353, 0.317647059, 0.501960784>;
#declare farge_Purple_Pizzazz = srgb <0.996078431, 0.305882353, 0.854901961>;
#declare farge_Purple_Taupe = srgb <0.31372549, 0.250980392, 0.301960784>;
#declare farge_Purple_Web = srgb <0.501960784, 0, 0.501960784>;
#declare farge_Purpureus = srgb <0.603921569, 0.305882353, 0.682352941>;
#declare farge_Quartz = srgb <0.317647059, 0.282352941, 0.309803922>;
#declare farge_Queen_Blue = srgb <0.262745098, 0.419607843, 0.584313725>;
#declare farge_Queen_Pink = srgb <0.909803922, 0.8, 0.843137255>;
#declare farge_Quinacridone_Magenta = srgb <0.556862745, 0.22745098, 0.349019608>;
#declare farge_Rackley = srgb <0.364705882, 0.541176471, 0.658823529>;
#declare farge_Raisin_Black = srgb <0.141176471, 0.129411765, 0.141176471>;
#declare farge_Rajah = srgb <0.984313725, 0.670588235, 0.376470588>;
#declare farge_Raspberry = srgb <0.890196078, 0.043137255, 0.364705882>;
#declare farge_Raspberry_Glace = srgb <0.568627451, 0.37254902, 0.42745098>;
#declare farge_Raspberry_Pink = srgb <0.88627451, 0.31372549, 0.596078431>;
#declare farge_Raspberry_Rose = srgb <0.701960784, 0.266666667, 0.423529412>;
#declare farge_Raw_Sienna = srgb <0.839215686, 0.541176471, 0.349019608>;
#declare farge_Raw_Umber = srgb <0.509803922, 0.4, 0.266666667>;
#declare farge_Razzle_Dazzle_Rose = srgb <1, 0.2, 0.8>;
#declare farge_Razzmatazz = srgb <0.890196078, 0.145098039, 0.419607843>;
#declare farge_Rebecca_Purple = srgb <0.4, 0.2, 0.6>;
#declare farge_Red_Brown = srgb <0.647058824, 0.164705882, 0.164705882>;
#declare farge_Red_Devil = srgb <0.525490196, 0.003921569, 0.066666667>;
#declare farge_Red_Munsell = srgb <0.949019608, 0, 0.235294118>;
#declare farge_Red_NCS = srgb <0.768627451, 0.007843137, 0.2>;
#declare farge_Red_Pantone = srgb <0.929411765, 0.160784314, 0.223529412>;
#declare farge_Red_Pigment = srgb <0.929411765, 0.109803922, 0.141176471>;
#declare farge_Red_Purple = srgb <0.894117647, 0, 0.470588235>;
#declare farge_Red_RYB = srgb <0.996078431, 0.152941176, 0.070588235>;
#declare farge_Red_Violet = srgb <0.780392157, 0.082352941, 0.521568627>;
#declare farge_Redwood = srgb <0.643137255, 0.352941176, 0.321568627>;
#declare farge_Regalia = srgb <0.321568627, 0.176470588, 0.501960784>;
#declare farge_Resolution_Blue = srgb <0, 0.137254902, 0.529411765>;
#declare farge_Rhythm = srgb <0.466666667, 0.462745098, 0.588235294>;
#declare farge_Rich_Black = srgb <0, 0.250980392, 0.250980392>;
#declare farge_Rich_Black_FOGRA29 = srgb <0.003921569, 0.043137255, 0.074509804>;
#declare farge_Rich_Black_FOGRA39 = srgb <0.003921569, 0.007843137, 0.011764706>;
#declare farge_Rich_Brilliant_Lavender = srgb <0.945098039, 0.654901961, 0.996078431>;
#declare farge_Rich_Carmine = srgb <0.843137255, 0, 0.250980392>;
#declare farge_Rich_Electric_Blue = srgb <0.031372549, 0.57254902, 0.815686275>;
#declare farge_Rich_Lavender = srgb <0.654901961, 0.419607843, 0.811764706>;
#declare farge_Rich_Lilac = srgb <0.71372549, 0.4, 0.823529412>;
#declare farge_Rich_Maroon = srgb <0.690196078, 0.188235294, 0.376470588>;
#declare farge_Rifle_Green = srgb <0.266666667, 0.298039216, 0.219607843>;
#declare farge_Roast_Coffee = srgb <0.439215686, 0.258823529, 0.254901961>;
#declare farge_Rocket_Metallic = srgb <0.541176471, 0.498039216, 0.501960784>;
#declare farge_Roman_Silver = srgb <0.51372549, 0.537254902, 0.588235294>;
#declare farge_Rose = srgb <1, 0, 0.498039216>;
#declare farge_Rose_Bonbon = srgb <0.976470588, 0.258823529, 0.619607843>;
#declare farge_Rose_Ebony = srgb <0.403921569, 0.282352941, 0.274509804>;
#declare farge_Rose_Gold = srgb <0.717647059, 0.431372549, 0.474509804>;
#declare farge_Rose_Madder = srgb <0.890196078, 0.149019608, 0.211764706>;
#declare farge_Rose_Pink = srgb <1, 0.4, 0.8>;
#declare farge_Rose_Quartz = srgb <0.666666667, 0.596078431, 0.662745098>;
#declare farge_Rose_Red = srgb <0.760784314, 0.117647059, 0.337254902>;
#declare farge_Rose_Taupe = srgb <0.564705882, 0.364705882, 0.364705882>;
#declare farge_Rose_Vale = srgb <0.670588235, 0.305882353, 0.321568627>;
#declare farge_Rosewood = srgb <0.396078431, 0, 0.043137255>;
#declare farge_Rosso_Corsa = srgb <0.831372549, 0, 0>;
#declare farge_Rosy_Brown = srgb <0.737254902, 0.560784314, 0.560784314>;
#declare farge_Royal_Azure = srgb <0, 0.219607843, 0.658823529>;
#declare farge_Royal_Blue_2 = srgb <0.254901961, 0.411764706, 0.882352941>;
#declare farge_Royal_Blue_Dark = srgb <0, 0.137254902, 0.4>;
#declare farge_Royal_Blue_Light = srgb <0.254901961, 0.411764706, 0.882352941>;
#declare farge_Royal_Fuchsia = srgb <0.792156863, 0.17254902, 0.57254902>;
#declare farge_Royal_Purple = srgb <0.470588235, 0.317647059, 0.662745098>;
#declare farge_Royal_Yellow = srgb <0.980392157, 0.854901961, 0.368627451>;
#declare farge_Ruber = srgb <0.807843137, 0.274509804, 0.462745098>;
#declare farge_Rubine_Red = srgb <0.819607843, 0, 0.337254902>;
#declare farge_Ruby = srgb <0.878431373, 0.066666667, 0.37254902>;
#declare farge_Ruby_Red = srgb <0.607843137, 0.066666667, 0.117647059>;
#declare farge_Ruddy = srgb <1, 0, 0.156862745>;
#declare farge_Ruddy_Brown = srgb <0.733333333, 0.396078431, 0.156862745>;
#declare farge_Ruddy_Pink = srgb <0.882352941, 0.556862745, 0.588235294>;
#declare farge_Rufous = srgb <0.658823529, 0.109803922, 0.02745098>;
#declare farge_Russet = srgb <0.501960784, 0.274509804, 0.105882353>;
#declare farge_Russian_Green = srgb <0.403921569, 0.57254902, 0.403921569>;
#declare farge_Russian_Violet = srgb <0.196078431, 0.090196078, 0.301960784>;
#declare farge_Rust = srgb <0.717647059, 0.254901961, 0.054901961>;
#declare farge_Sacramento_State_Green = srgb <0.015686275, 0.223529412, 0.152941176>;
#declare farge_Saddle_Brown = srgb <0.545098039, 0.270588235, 0.074509804>;
#declare farge_Safety_Orange = srgb <1, 0.470588235, 0>;
#declare farge_Safety_Orange_Blaze_Orange = srgb <1, 0.403921569, 0>;
#declare farge_Safety_Yellow = srgb <0.933333333, 0.823529412, 0.007843137>;
#declare farge_Saffron = srgb <0.956862745, 0.768627451, 0.188235294>;
#declare farge_Sage = srgb <0.737254902, 0.721568627, 0.541176471>;
#declare farge_Salmon = srgb <0.980392157, 0.501960784, 0.447058824>;
#declare farge_Salmon_Pink = srgb <1, 0.568627451, 0.643137255>;
#declare farge_Sand = srgb <0.760784314, 0.698039216, 0.501960784>;
#declare farge_Sand_Dune = srgb <0.588235294, 0.443137255, 0.090196078>;
#declare farge_Sandstorm = srgb <0.925490196, 0.835294118, 0.250980392>;
#declare farge_Sandy_Brown = srgb <0.956862745, 0.643137255, 0.376470588>;
#declare farge_Sandy_Taupe = srgb <0.588235294, 0.443137255, 0.090196078>;
#declare farge_Sangria = srgb <0.57254902, 0, 0.039215686>;
#declare farge_Sap_Green = srgb <0.31372549, 0.490196078, 0.164705882>;
#declare farge_Sapphire = srgb <0.058823529, 0.321568627, 0.729411765>;
#declare farge_Sapphire_Blue = srgb <0, 0.403921569, 0.647058824>;
#declare farge_Satin_Sheen_Gold = srgb <0.796078431, 0.631372549, 0.207843137>;
#declare farge_Scarlet = srgb <1, 0.141176471, 0>;
#declare farge_Schauss_Pink = srgb <1, 0.568627451, 0.68627451>;
#declare farge_School_Bus_Yellow = srgb <1, 0.847058824, 0>;
#declare farge_Screamin_Green = srgb <0.462745098, 1, 0.478431373>;
#declare farge_Sea_Blue = srgb <0, 0.411764706, 0.580392157>;
#declare farge_Sea_Green = srgb <0.180392157, 0.545098039, 0.341176471>;
#declare farge_Seal_Brown = srgb <0.349019608, 0.149019608, 0.043137255>;
#declare farge_Seashell = srgb <1, 0.960784314, 0.933333333>;
#declare farge_Selective_Yellow = srgb <1, 0.729411765, 0>;
#declare farge_Sepia = srgb <0.439215686, 0.258823529, 0.078431373>;
#declare farge_Shadow = srgb <0.541176471, 0.474509804, 0.364705882>;
#declare farge_Shampoo = srgb <1, 0.811764706, 0.945098039>;
#declare farge_Shamrock_Green = srgb <0, 0.619607843, 0.376470588>;
#declare farge_Shocking_Pink = srgb <0.988235294, 0.058823529, 0.752941176>;
#declare farge_Sienna = srgb <0.533333333, 0.176470588, 0.090196078>;
#declare farge_Silver = srgb <0.752941176, 0.752941176, 0.752941176>;
#declare farge_Silver_Chalice = srgb <0.674509804, 0.674509804, 0.674509804>;
#declare farge_Silver_Lake_Blue = srgb <0.364705882, 0.537254902, 0.729411765>;
#declare farge_Silver_Metallic = srgb <0.666666667, 0.662745098, 0.678431373>;
#declare farge_Silver_Pink = srgb <0.768627451, 0.682352941, 0.678431373>;
#declare farge_Silver_Sand = srgb <0.749019608, 0.756862745, 0.760784314>;
#declare farge_Sinopia = srgb <0.796078431, 0.254901961, 0.043137255>;
#declare farge_Sizzling_Sunrise = srgb <1, 0.858823529, 0>;
#declare farge_Skobeloff = srgb <0, 0.454901961, 0.454901961>;
#declare farge_Sky_Blue = srgb <0.529411765, 0.807843137, 0.921568627>;
#declare farge_Sky_Magenta = srgb <0.811764706, 0.443137255, 0.68627451>;
#declare farge_Slate_Blue = srgb <0.415686275, 0.352941176, 0.803921569>;
#declare farge_Slate_Gray = srgb <0.439215686, 0.501960784, 0.564705882>;
#declare farge_Smalt_Dark_Powder_Blue = srgb <0, 0.2, 0.6>;
#declare farge_Smitten = srgb <0.784313725, 0.254901961, 0.525490196>;
#declare farge_Smoke = srgb <0.450980392, 0.509803922, 0.462745098>;
#declare farge_Smoky_Black = srgb <0.062745098, 0.047058824, 0.031372549>;
#declare farge_Smoky_Topaz = srgb <0.576470588, 0.239215686, 0.254901961>;
#declare farge_Snow = srgb <1, 0.980392157, 0.980392157>;
#declare farge_Soap = srgb <0.807843137, 0.784313725, 0.937254902>;
#declare farge_Solid_Pink = srgb <0.537254902, 0.219607843, 0.262745098>;
#declare farge_Space_Cadet = srgb <0.11372549, 0.160784314, 0.317647059>;
#declare farge_Spanish_Bistre = srgb <0.501960784, 0.458823529, 0.196078431>;
#declare farge_Spanish_Blue = srgb <0, 0.439215686, 0.721568627>;
#declare farge_Spanish_Carmine = srgb <0.819607843, 0, 0.278431373>;
#declare farge_Spanish_Crimson = srgb <0.898039216, 0.101960784, 0.298039216>;
#declare farge_Spanish_Gray = srgb <0.596078431, 0.596078431, 0.596078431>;
#declare farge_Spanish_Green = srgb <0, 0.568627451, 0.31372549>;
#declare farge_Spanish_Orange = srgb <0.909803922, 0.380392157, 0>;
#declare farge_Spanish_Pink = srgb <0.968627451, 0.749019608, 0.745098039>;
#declare farge_Spanish_Red = srgb <0.901960784, 0, 0.149019608>;
#declare farge_Spanish_Violet = srgb <0.298039216, 0.156862745, 0.509803922>;
#declare farge_Spanish_Viridian = srgb <0, 0.498039216, 0.360784314>;
#declare farge_Spartan_Crimson = srgb <0.619607843, 0.074509804, 0.08627451>;
#declare farge_Spiro_Disco_Ball = srgb <0.058823529, 0.752941176, 0.988235294>;
#declare farge_Spring_Bud = srgb <0.654901961, 0.988235294, 0>;
#declare farge_Spring_Frost = srgb <0.529411765, 1, 0.164705882>;
#declare farge_Spring_Green = srgb <0, 1, 0.498039216>;
#declare farge_St_Patricks_Blue = srgb <0.137254902, 0.160784314, 0.478431373>;
#declare farge_Star_Command_Blue = srgb <0, 0.482352941, 0.721568627>;
#declare farge_Steel_Blue = srgb <0.274509804, 0.509803922, 0.705882353>;
#declare farge_Steel_Pink = srgb <0.8, 0.2, 0.8>;
#declare farge_Stil_de_Grain_Yellow = srgb <0.980392157, 0.854901961, 0.368627451>;
#declare farge_Stizza = srgb <0.6, 0, 0>;
#declare farge_Stormcloud = srgb <0.309803922, 0.4, 0.415686275>;
#declare farge_Straw = srgb <0.894117647, 0.850980392, 0.435294118>;
#declare farge_Strawberry = srgb <0.988235294, 0.352941176, 0.552941176>;
#declare farge_Sunray = srgb <0.890196078, 0.670588235, 0.341176471>;
#declare farge_Sunset = srgb <0.980392157, 0.839215686, 0.647058824>;
#declare farge_Sunset_Orange = srgb <0.992156863, 0.368627451, 0.325490196>;
#declare farge_Super_Pink = srgb <0.811764706, 0.419607843, 0.662745098>;
#declare farge_Tan = srgb <0.823529412, 0.705882353, 0.549019608>;
#declare farge_Tangelo = srgb <0.976470588, 0.301960784, 0>;
#declare farge_Tangerine = srgb <0.949019608, 0.521568627, 0>;
#declare farge_Tangerine_Yellow = srgb <1, 0.8, 0>;
#declare farge_Tango_Pink = srgb <0.894117647, 0.443137255, 0.478431373>;
#declare farge_Taupe = srgb <0.282352941, 0.235294118, 0.196078431>;
#declare farge_Taupe_Gray = srgb <0.545098039, 0.521568627, 0.537254902>;
#declare farge_Tea_Green = srgb <0.815686275, 0.941176471, 0.752941176>;
#declare farge_Tea_Rose = srgb <0.956862745, 0.760784314, 0.760784314>;
#declare farge_Tea_Rose = srgb <0.97254902, 0.51372549, 0.474509804>;
#declare farge_Teal = srgb <0, 0.501960784, 0.501960784>;
#declare farge_Teal_Blue = srgb <0.211764706, 0.458823529, 0.533333333>;
#declare farge_Teal_Deer = srgb <0.6, 0.901960784, 0.701960784>;
#declare farge_Teal_Green = srgb <0, 0.509803922, 0.498039216>;
#declare farge_Telemagenta = srgb <0.811764706, 0.203921569, 0.462745098>;
#declare farge_Tenne_Tawny = srgb <0.803921569, 0.341176471, 0>;
#declare farge_Terra_Cotta = srgb <0.88627451, 0.447058824, 0.356862745>;
#declare farge_Thulian_Pink = srgb <0.870588235, 0.435294118, 0.631372549>;
#declare farge_Tickle_Me_Pink = srgb <0.988235294, 0.537254902, 0.674509804>;
#declare farge_Tiffany_Blue = srgb <0.039215686, 0.729411765, 0.709803922>;
#declare farge_Tigers_Eye = srgb <0.878431373, 0.552941176, 0.235294118>;
#declare farge_Timberwolf = srgb <0.858823529, 0.843137255, 0.823529412>;
#declare farge_Titanium_Yellow = srgb <0.933333333, 0.901960784, 0>;
#declare farge_Tomato = srgb <1, 0.388235294, 0.278431373>;
#declare farge_Toolbox = srgb <0.454901961, 0.423529412, 0.752941176>;
#declare farge_Topaz = srgb <1, 0.784313725, 0.48627451>;
#declare farge_Tractor_Red = srgb <0.992156863, 0.054901961, 0.207843137>;
#declare farge_Trolley_Grey = srgb <0.501960784, 0.501960784, 0.501960784>;
#declare farge_True_Blue = srgb <0.176470588, 0.407843137, 0.768627451>;
#declare farge_Trypan_Blue = srgb <0.109803922, 0.019607843, 0.701960784>;
#declare farge_Tufts_Blue = srgb <0.243137255, 0.556862745, 0.870588235>;
#declare farge_Tulip = srgb <1, 0.529411765, 0.552941176>;
#declare farge_Tumbleweed = srgb <0.870588235, 0.666666667, 0.533333333>;
#declare farge_Tumblr = srgb <0.17254902, 0.278431373, 0.384313725>;
#declare farge_Turkish_Rose = srgb <0.709803922, 0.447058824, 0.505882353>;
#declare farge_Turquoise = srgb <0.250980392, 0.878431373, 0.815686275>;
#declare farge_Turquoise_Blue = srgb <0, 1, 0.937254902>;
#declare farge_Turquoise_Green = srgb <0.62745098, 0.839215686, 0.705882353>;
#declare farge_Turtle_Green = srgb <0.541176471, 0.603921569, 0.356862745>;
#declare farge_Tuscan = srgb <0.980392157, 0.839215686, 0.647058824>;
#declare farge_Tuscan_Brown = srgb <0.435294118, 0.305882353, 0.215686275>;
#declare farge_Tuscan_Red = srgb <0.48627451, 0.282352941, 0.282352941>;
#declare farge_Tuscan_Tan = srgb <0.650980392, 0.482352941, 0.356862745>;
#declare farge_Tuscany = srgb <0.752941176, 0.6, 0.6>;
#declare farge_Tyrian_Purple = srgb <0.4, 0.007843137, 0.235294118>;
#declare farge_UA_Blue = srgb <0, 0.2, 0.666666667>;
#declare farge_UA_Red = srgb <0.850980392, 0, 0.298039216>;
#declare farge_Ube = srgb <0.533333333, 0.470588235, 0.764705882>;
#declare farge_UCLA_Blue = srgb <0.325490196, 0.407843137, 0.584313725>;
#declare farge_UCLA_Gold = srgb <1, 0.701960784, 0>;
#declare farge_UFO_Green = srgb <0.235294118, 0.815686275, 0.439215686>;
#declare farge_Ultra_Pink = srgb <1, 0.435294118, 1>;
#declare farge_Ultra_Red = srgb <0.988235294, 0.423529412, 0.521568627>;
#declare farge_Ultramarine = srgb <0.247058824, 0, 1>;
#declare farge_Ultramarine_Blue = srgb <0.254901961, 0.4, 0.960784314>;
#declare farge_Umber = srgb <0.388235294, 0.317647059, 0.278431373>;
#declare farge_Unbleached_Silk = srgb <1, 0.866666667, 0.792156863>;
#declare farge_United_Nations_Blue = srgb <0.356862745, 0.57254902, 0.898039216>;
#declare farge_University_of_California_Gold = srgb <0.717647059, 0.529411765, 0.152941176>;
#declare farge_University_of_Tennessee_Orange = srgb <0.968627451, 0.498039216, 0>;
#declare farge_Unmellow_Yellow = srgb <1, 1, 0.4>;
#declare farge_UP_Forest_Green = srgb <0.003921569, 0.266666667, 0.129411765>;
#declare farge_UP_Maroon = srgb <0.482352941, 0.066666667, 0.074509804>;
#declare farge_Upsdell_Red = srgb <0.682352941, 0.125490196, 0.160784314>;
#declare farge_Uranian_Blue = srgb <0.68627451, 0.858823529, 0.960784314>;
#declare farge_Urobilin = srgb <0.882352941, 0.678431373, 0.129411765>;
#declare farge_USAFA_Blue = srgb <0, 0.309803922, 0.596078431>;
#declare farge_USC_Cardinal = srgb <0.6, 0, 0>;
#declare farge_USC_Gold = srgb <1, 0.8, 0>;
#declare farge_Utah_Crimson = srgb <0.82745098, 0, 0.247058824>;
#declare farge_Vanilla = srgb <0.952941176, 0.898039216, 0.670588235>;
#declare farge_Vanilla_Ice = srgb <0.952941176, 0.560784314, 0.662745098>;
#declare farge_Vegas_Gold = srgb <0.77254902, 0.701960784, 0.345098039>;
#declare farge_Venetian_Red = srgb <0.784313725, 0.031372549, 0.082352941>;
#declare farge_Verdigris = srgb <0.262745098, 0.701960784, 0.682352941>;
#declare farge_Vermilion = srgb <0.850980392, 0.219607843, 0.117647059>;
#declare farge_Vermilion = srgb <0.890196078, 0.258823529, 0.203921569>;
#declare farge_Veronica = srgb <0.62745098, 0.125490196, 0.941176471>;
#declare farge_Very_Light_Blue = srgb <0.4, 0.4, 1>;
#declare farge_Very_Light_Malachite_Green = srgb <0.392156863, 0.91372549, 0.525490196>;
#declare farge_Very_Pale_Orange = srgb <1, 0.874509804, 0.749019608>;
#declare farge_Very_Pale_Yellow = srgb <1, 1, 0.749019608>;
#declare farge_Violet = srgb <0.560784314, 0, 1>;
#declare farge_Violet_Blue = srgb <0.196078431, 0.290196078, 0.698039216>;
#declare farge_Violet_Red = srgb <0.968627451, 0.325490196, 0.580392157>;
#declare farge_Violet_RYB = srgb <0.525490196, 0.003921569, 0.68627451>;
#declare farge_Violet_Web = srgb <0.933333333, 0.509803922, 0.933333333>;
#declare farge_Viridian = srgb <0.250980392, 0.509803922, 0.42745098>;
#declare farge_Viridian_Green = srgb <0, 0.588235294, 0.596078431>;
#declare farge_Vista_Blue = srgb <0.48627451, 0.619607843, 0.850980392>;
#declare farge_Vivid_Auburn = srgb <0.57254902, 0.152941176, 0.141176471>;
#declare farge_Vivid_Burgundy = srgb <0.623529412, 0.11372549, 0.207843137>;
#declare farge_Vivid_Cerise = srgb <0.854901961, 0.11372549, 0.505882353>;
#declare farge_Vivid_Gamboge = srgb <1, 0.6, 0>;
#declare farge_Vivid_Mulberry = srgb <0.721568627, 0.047058824, 0.890196078>;
#declare farge_Vivid_Orange = srgb <1, 0.37254902, 0>;
#declare farge_Vivid_Orchid = srgb <0.8, 0, 1>;
#declare farge_Vivid_Raspberry = srgb <1, 0, 0.423529412>;
#declare farge_Vivid_Red = srgb <0.968627451, 0.050980392, 0.101960784>;
#declare farge_Vivid_Red_Tangelo = srgb <0.874509804, 0.380392157, 0.141176471>;
#declare farge_Vivid_Sky_Blue = srgb <0, 0.8, 1>;
#declare farge_Vivid_Tangelo = srgb <0.941176471, 0.454901961, 0.152941176>;
#declare farge_Vivid_Tangerine = srgb <1, 0.62745098, 0.537254902>;
#declare farge_Vivid_Violet = srgb <0.623529412, 0, 1>;
#declare farge_Vivid_Yellow = srgb <1, 0.890196078, 0.007843137>;
#declare farge_Volt = srgb <0.807843137, 1, 0>;
#declare farge_Warm_Black = srgb <0, 0.258823529, 0.258823529>;
#declare farge_Waterspout = srgb <0.643137255, 0.956862745, 0.976470588>;
#declare farge_Wenge = srgb <0.392156863, 0.329411765, 0.321568627>;
#declare farge_Wheat = srgb <0.960784314, 0.870588235, 0.701960784>;
#declare farge_White_Smoke = srgb <0.960784314, 0.960784314, 0.960784314>;
#declare farge_Wild_Blue_Yonder = srgb <0.635294118, 0.678431373, 0.815686275>;
#declare farge_Wild_Orchid = srgb <0.831372549, 0.439215686, 0.635294118>;
#declare farge_Wild_Strawberry = srgb <1, 0.262745098, 0.643137255>;
#declare farge_Wild_Watermelon = srgb <0.988235294, 0.423529412, 0.521568627>;
#declare farge_Willpower_Orange = srgb <0.992156863, 0.345098039, 0>;
#declare farge_Windsor_Tan = srgb <0.654901961, 0.333333333, 0.007843137>;
#declare farge_Wine = srgb <0.447058824, 0.184313725, 0.215686275>;
#declare farge_Wine_Dregs = srgb <0.403921569, 0.192156863, 0.278431373>;
#declare farge_Wood_Brown = srgb <0.756862745, 0.603921569, 0.419607843>;
#declare farge_X11_Alice_Blue = srgb <0.941176471, 0.97254902, 1>;
#declare farge_Xanadu = srgb <0.450980392, 0.525490196, 0.470588235>;
#declare farge_Xanthic = srgb <0.933333333, 0.929411765, 0.035294118>;
#declare farge_Xiketic = srgb <0.047058824, 0.007843137, 0.058823529>;
#declare farge_Yale_Blue = srgb <0.058823529, 0.301960784, 0.57254902>;
#declare farge_Yankees_Blue = srgb <0.109803922, 0.156862745, 0.254901961>;
#declare farge_Yellow_Green = srgb <0.603921569, 0.803921569, 0.196078431>;
#declare farge_Yellow_Munsell = srgb <0.937254902, 0.8, 0>;
#declare farge_Yellow_NCS = srgb <1, 0.82745098, 0>;
#declare farge_Yellow_Pantone = srgb <0.996078431, 0.874509804, 0>;
#declare farge_Yellow_Process = srgb <1, 0.937254902, 0>;
#declare farge_Yellow_Rose = srgb <1, 0.941176471, 0>;
#declare farge_Yellow_RYB = srgb <0.996078431, 0.996078431, 0.2>;
#declare farge_YInMn_Blue = srgb <0.180392157, 0.31372549, 0.564705882>;
#declare farge_Zaffre = srgb <0, 0.078431373, 0.658823529>;
#declare farge_Zinnwaldite_Brown = srgb <0.17254902, 0.08627451, 0.031372549>;
#declare farge_Zomp = srgb <0.223529412, 0.654901961, 0.556862745>;

// Alternative farge color names
#declare farge_Aqua = Cyan;
#declare farge_Cool_Black = Black;
#declare farge_Electric_Green = Green;
#declare farge_Fuchsia = Magenta;
#declare garge_Spanish_Sky_Blue = Cyan;

// Named HTML color names
#declare HTML_Gray = srgb <0.501960784, 0.501960784, 0.501960784>;
#declare HTML_Green = srgb <0, 0.501960784, 0>;
#declare HTML_Maroon = srgb <0.501960784, 0, 0>;
#declare HTML_Navy = srgb <0, 0, 0.501960784>;
#declare HTML_Olive = srgb <0.501960784, 0.501960784, 0>;
#declare HTML_Purple = srgb <0.501960784, 0, 0.501960784>;
#declare HTML_Silver = srgb <0.752941176, 0.752941176, 0.752941176>;
#declare HTML_Teal = srgb <0, 0.501960784, 0.501960784>;

// Alternative HTML color names
#declare HTML_Aqua = Cyan;
#declare HTML_Black = Black;
#declare HTML_Blue = Blue;
#declare HTML_Fuchsia = Magenta;
#declare HTML_Lime = Green;
#declare HTML_Red = Red;
#declare HTML_White = White;
#declare HTML_Yellow = Yellow;

// X11 color names
#declare X11_Antique_White = srgb <0.980392157, 0.921568627, 0.843137255>;
#declare X11_Aquamarine = srgb <0.498039216, 1, 0.831372549>;
#declare X11_Azure = srgb <0.941176471, 1, 1>;
#declare X11_Beige = srgb <0.960784314, 0.960784314, 0.862745098>;
#declare X11_Bisque = srgb <1, 0.894117647, 0.768627451>;
#declare X11_Blanched_Almond = srgb <1, 0.921568627, 0.803921569>;
#declare X11_Blue_Violet = srgb <0.541176471, 0.168627451, 0.88627451>;
#declare X11_Brown = srgb <0.647058824, 0.164705882, 0.164705882>;
#declare X11_Burlywood = srgb <0.870588235, 0.721568627, 0.529411765>;
#declare X11_Cadet_Blue = srgb <0.37254902, 0.619607843, 0.62745098>;
#declare X11_Chartreuse = srgb <0.498039216, 1, 0>;
#declare X11_Chocolate = srgb <0.823529412, 0.411764706, 0.117647059>;
#declare X11_Coral = srgb <1, 0.498039216, 0.31372549>;
#declare X11_Cornflower_Blue = srgb <0.392156863, 0.584313725, 0.929411765>;
#declare X11_Cornsilk = srgb <1, 0.97254902, 0.862745098>;
#declare X11_Crimson = srgb <0.862745098, 0.078431373, 0.235294118>;
#declare X11_Dark_Blue = srgb <0, 0, 0.545098039>;
#declare X11_Dark_Cyan = srgb <0, 0.545098039, 0.545098039>;
#declare X11_Dark_Goldenrod = srgb <0.721568627, 0.525490196, 0.043137255>;
#declare X11_Dark_Gray = srgb <0.662745098, 0.662745098, 0.662745098>;
#declare X11_Dark_Green = srgb <0, 0.392156863, 0>;
#declare X11_Dark_Khaki = srgb <0.741176471, 0.717647059, 0.419607843>;
#declare X11_Dark_Magenta = srgb <0.545098039, 0, 0.545098039>;
#declare X11_Dark_Olive_Green = srgb <0.333333333, 0.419607843, 0.184313725>;
#declare X11_Dark_Orange = srgb <1, 0.549019608, 0>;
#declare X11_Dark_Orchid = srgb <0.6, 0.196078431, 0.8>;
#declare X11_Dark_Red = srgb <0.545098039, 0, 0>;
#declare X11_Dark_Salmon = srgb <0.91372549, 0.588235294, 0.478431373>;
#declare X11_Dark_Sea_Green = srgb <0.560784314, 0.737254902, 0.560784314>;
#declare X11_Dark_Slate_Blue = srgb <0.282352941, 0.239215686, 0.545098039>;
#declare X11_Dark_Slate_Gray = srgb <0.184313725, 0.309803922, 0.309803922>;
#declare X11_Dark_Turquoise = srgb <0, 0.807843137, 0.819607843>;
#declare X11_Dark_Violet = srgb <0.580392157, 0, 0.82745098>;
#declare X11_Deep_Pink = srgb <1, 0.078431373, 0.576470588>;
#declare X11_Deep_Sky_Blue = srgb <0, 0.749019608, 1>;
#declare X11_Dim_Gray = srgb <0.411764706, 0.411764706, 0.411764706>;
#declare X11_Dodger_Blue = srgb <0.117647059, 0.564705882, 1>;
#declare X11_Firebrick = srgb <0.698039216, 0.133333333, 0.133333333>;
#declare X11_Floral_White = srgb <1, 0.980392157, 0.941176471>;
#declare X11_Forest_Green = srgb <0.133333333, 0.545098039, 0.133333333>;
#declare X11_Gainsboro = srgb <0.862745098, 0.862745098, 0.862745098>;
#declare X11_Ghost_White = srgb <0.97254902, 0.97254902, 1>;
#declare X11_Gold = srgb <1, 0.843137255, 0>;
#declare X11_Goldenrod = srgb <0.854901961, 0.647058824, 0.125490196>;
#declare X11_Gray = srgb <0.745098039, 0.745098039, 0.745098039>;
#declare X11_Green_Yellow = srgb <0.678431373, 1, 0.184313725>;
#declare X11_Honeydew = srgb <0.941176471, 1, 0.941176471>;
#declare X11_Hot_Pink = srgb <1, 0.411764706, 0.705882353>;
#declare X11_Indian_Red = srgb <0.803921569, 0.360784314, 0.360784314>;
#declare X11_Indigo = srgb <0.294117647, 0, 0.509803922>;
#declare X11_Ivory = srgb <1, 1, 0.941176471>;
#declare X11_Khaki = srgb <0.941176471, 0.901960784, 0.549019608>;
#declare X11_Lavender = srgb <0.901960784, 0.901960784, 0.980392157>;
#declare X11_Lavender_Blush = srgb <1, 0.941176471, 0.960784314>;
#declare X11_Lawn_Green = srgb <0.48627451, 0.988235294, 0>;
#declare X11_Lemon_Chiffon = srgb <1, 0.980392157, 0.803921569>;
#declare X11_Light_Blue = srgb <0.678431373, 0.847058824, 0.901960784>;
#declare X11_Light_Coral = srgb <0.941176471, 0.501960784, 0.501960784>;
#declare X11_Light_Cyan = srgb <0.878431373, 1, 1>;
#declare X11_Light_Goldenrod = srgb <0.980392157, 0.980392157, 0.823529412>;
#declare X11_Light_Gray = srgb <0.82745098, 0.82745098, 0.82745098>;
#declare X11_Light_Green = srgb <0.564705882, 0.933333333, 0.564705882>;
#declare X11_Light_Pink = srgb <1, 0.71372549, 0.756862745>;
#declare X11_Light_Salmon = srgb <1, 0.62745098, 0.478431373>;
#declare X11_Light_Sea_Green = srgb <0.125490196, 0.698039216, 0.666666667>;
#declare X11_Light_Sky_Blue = srgb <0.529411765, 0.807843137, 0.980392157>;
#declare X11_Light_Slate_Gray = srgb <0.466666667, 0.533333333, 0.6>;
#declare X11_Light_Steel_Blue = srgb <0.690196078, 0.768627451, 0.870588235>;
#declare X11_Light_Yellow = srgb <1, 1, 0.878431373>;
#declare X11_Lime_Green = srgb <0.196078431, 0.803921569, 0.196078431>;
#declare X11_Linen = srgb <0.980392157, 0.941176471, 0.901960784>;
#declare X11_Maroon = srgb <0.690196078, 0.188235294, 0.376470588>;
#declare X11_Medium_Aquamarine = srgb <0.4, 0.803921569, 0.666666667>;
#declare X11_Medium_Blue = srgb <0, 0, 0.803921569>;
#declare X11_Medium_Orchid = srgb <0.729411765, 0.333333333, 0.82745098>;
#declare X11_Medium_Purple = srgb <0.576470588, 0.439215686, 0.858823529>;
#declare X11_Medium_Sea_Green = srgb <0.235294118, 0.701960784, 0.443137255>;
#declare X11_Medium_Slate_Blue = srgb <0.482352941, 0.407843137, 0.933333333>;
#declare X11_Medium_Spring_Green = srgb <0, 0.980392157, 0.603921569>;
#declare X11_Medium_Turquoise = srgb <0.282352941, 0.819607843, 0.8>;
#declare X11_Medium_Violet_Red = srgb <0.780392157, 0.082352941, 0.521568627>;
#declare X11_Midnight_Blue = srgb <0.098039216, 0.098039216, 0.439215686>;
#declare X11_Mint_Cream = srgb <0.960784314, 1, 0.980392157>;
#declare X11_Misty_Rose = srgb <1, 0.894117647, 0.882352941>;
#declare X11_Moccasin = srgb <1, 0.894117647, 0.709803922>;
#declare X11_Navajo_White = srgb <1, 0.870588235, 0.678431373>;
#declare X11_Navy_Blue = srgb <0, 0, 0.501960784>;
#declare X11_Old_Lace = srgb <0.992156863, 0.960784314, 0.901960784>;
#declare X11_Olive = srgb <0.501960784, 0.501960784, 0>;
#declare X11_Olive_Drab = srgb <0.419607843, 0.556862745, 0.137254902>;
#declare X11_Orange = srgb <1, 0.647058824, 0>;
#declare X11_Orange_Red = srgb <1, 0.270588235, 0>;
#declare X11_Orchid = srgb <0.854901961, 0.439215686, 0.839215686>;
#declare X11_Pale_Goldenrod = srgb <0.933333333, 0.909803922, 0.666666667>;
#declare X11_Pale_Green = srgb <0.596078431, 0.984313725, 0.596078431>;
#declare X11_Pale_Turquoise = srgb <0.68627451, 0.933333333, 0.933333333>;
#declare X11_Pale_Violet_Red = srgb <0.858823529, 0.439215686, 0.576470588>;
#declare X11_Papaya_Whip = srgb <1, 0.937254902, 0.835294118>;
#declare X11_Peach_Puff = srgb <1, 0.854901961, 0.725490196>;
#declare X11_Peru = srgb <0.803921569, 0.521568627, 0.247058824>;
#declare X11_Pink = srgb <1, 0.752941176, 0.796078431>;
#declare X11_Plum = srgb <0.866666667, 0.62745098, 0.866666667>;
#declare X11_Powder_Blue = srgb <0.690196078, 0.878431373, 0.901960784>;
#declare X11_Purple = srgb <0.62745098, 0.125490196, 0.941176471>;
#declare X11_Rebecca_Purple = srgb <0.4, 0.2, 0.6>;
#declare X11_Rosy_Brown = srgb <0.737254902, 0.560784314, 0.560784314>;
#declare X11_Royal_Blue = srgb <0.254901961, 0.411764706, 0.882352941>;
#declare X11_Saddle_Brown = srgb <0.545098039, 0.270588235, 0.074509804>;
#declare X11_Salmon = srgb <0.980392157, 0.501960784, 0.447058824>;
#declare X11_Sandy_Brown = srgb <0.956862745, 0.643137255, 0.376470588>;
#declare X11_Sea_Green = srgb <0.180392157, 0.545098039, 0.341176471>;
#declare X11_Seashell = srgb <1, 0.960784314, 0.933333333>;
#declare X11_Sienna = srgb <0.62745098, 0.321568627, 0.176470588>;
#declare X11_Silver = srgb <0.752941176, 0.752941176, 0.752941176>;
#declare X11_Sky_Blue = srgb <0.529411765, 0.807843137, 0.921568627>;
#declare X11_Slate_Blue = srgb <0.415686275, 0.352941176, 0.803921569>;
#declare X11_Slate_Gray = srgb <0.439215686, 0.501960784, 0.564705882>;
#declare X11_Snow = srgb <1, 0.980392157, 0.980392157>;
#declare X11_Spring_Green = srgb <0, 1, 0.498039216>;
#declare X11_Steel_Blue = srgb <0.274509804, 0.509803922, 0.705882353>;
#declare X11_Tan = srgb <0.823529412, 0.705882353, 0.549019608>;
#declare X11_Teal = srgb <0, 0.501960784, 0.501960784>;
#declare X11_Thistle = srgb <0.847058824, 0.749019608, 0.847058824>;
#declare X11_Tomato = srgb <1, 0.388235294, 0.278431373>;
#declare X11_Turquoise = srgb <0.250980392, 0.878431373, 0.815686275>;
#declare X11_Violet = srgb <0.933333333, 0.509803922, 0.933333333>;
#declare X11_Web_Gray = srgb <0.501960784, 0.501960784, 0.501960784>;
#declare X11_Web_Green = srgb <0, 0.501960784, 0>;
#declare X11_Web_Maroon = srgb <0.501960784, 0, 0>;
#declare X11_Web_Purple = srgb <0.501960784, 0, 0.501960784>;
#declare X11_Wheat = srgb <0.960784314, 0.870588235, 0.701960784>;
#declare X11_White_Smoke = srgb <0.960784314, 0.960784314, 0.960784314>;
#declare X11_Yellow_Green = srgb <0.603921569, 0.803921569, 0.196078431>;


// Alternative X11 color names
#declare X11_Aqua = Cyan;
#declare X11_Black = Black;
#declare X11_Blue = Blue;
#declare X11_Cyan = Cyan;
#declare X11_Dark_Grey = X11_Dark_Gray;
#declare X11_Dark_Slate_Grey = X11_Dark_Slate_Gray;
#declare X11_Dim_Grey = X11_Dim_Gray;
#declare X11_Fuchsia = Magenta;
#declare X11_Green = Green;
#declare X11_Grey = X11_Gray;
#declare X11_Light_Grey = X11_Light_Gray;
#declare X11_Light_Slate_Grey = X11_Light_Slate_Gray;
#declare X11_Lime = X11_Green;
#declare X11_Magenta = Magenta;
#declare X11_Navy = X11_Navy_Blue;
#declare X11_Red = Red;
#declare X11_Slate_Grey = X11_Slate_Gray;
#declare X11_Web_Grey = X11_Web_Gray;
#declare X11_White = White;
#declare X11_Yellow = Yellow;

// Official LEGO™ Colors
#declare Lego_Black = srgb <0.105882353, 0.164705882, 0.203921569>;
#declare Lego_Black_Metallic = srgb <0.08627451, 0.11372549, 0.196078431>;
#declare Lego_Brick_Yellow = srgb <0.843137255, 0.77254902, 0.6>;
#declare Lego_Bright_Blue = srgb <0.050980392, 0.411764706, 0.670588235>;
#declare Lego_Bright_Bluish_Green = srgb <0, 0.560784314, 0.607843137>;
#declare Lego_Bright_Bluish_Violet = srgb <0.262745098, 0.329411765, 0.576470588>;
#declare Lego_Bright_Green = srgb <0.294117647, 0.592156863, 0.290196078>;
#declare Lego_Bright_Orange = srgb <0.854901961, 0.521568627, 0.250980392>;
#declare Lego_Bright_Purple = srgb <0.803921569, 0.384313725, 0.596078431>;
#declare Lego_Bright_Red = srgb <0.768627451, 0.156862745, 0.105882353>;
#declare Lego_Bright_Reddish_Lilac = srgb <0.556862745, 0.258823529, 0.521568627>;
#declare Lego_Bright_Reddish_Orange = srgb <0.82745098, 0.435294118, 0.298039216>;
#declare Lego_Bright_Reddish_Violet = srgb <0.57254902, 0.223529412, 0.470588235>;
#declare Lego_Bright_Violet = srgb <0.419607843, 0.196078431, 0.482352941>;
#declare Lego_Bright_Yellow = srgb <0.960784314, 0.803921569, 0.184313725>;
#declare Lego_Bright_Yellowish_Green = srgb <0.643137255, 0.741176471, 0.274509804>;
#declare Lego_Bright_Yellowish_Orange = srgb <0.88627451, 0.607843137, 0.247058824>;
#declare Lego_Brown = srgb <0.48627451, 0.360784314, 0.270588235>;
#declare Lego_Cool_Yellow = srgb <0.992156863, 0.917647059, 0.549019608>;
#declare Lego_Curry = srgb <0.843137255, 0.662745098, 0.294117647>;
#declare Lego_Dark_Curry = srgb <0.690196078, 0.556862745, 0.266666667>;
#declare Lego_Dark_Green = srgb <0.156862745, 0.498039216, 0.274509804>;
#declare Lego_Dark_Grey = srgb <0.42745098, 0.431372549, 0.423529412>;
#declare Lego_Dark_Grey_Metallic = srgb <0.341176471, 0.345098039, 0.341176471>;
#declare Lego_Dark_Nougat = srgb <0.682352941, 0.478431373, 0.349019608>;
#declare Lego_Dark_Orange = srgb <0.62745098, 0.37254902, 0.203921569>;
#declare Lego_Dark_Red = srgb <0.482352941, 0.180392157, 0.184313725>;
#declare Lego_Dark_Royal_Blue = srgb <0.137254902, 0.278431373, 0.545098039>;
#declare Lego_Dark_Stone_Grey = srgb <0.388235294, 0.37254902, 0.380392157>;
#declare Lego_Dove_Blue = srgb <0.490196078, 0.733333333, 0.866666667>;
#declare Lego_Earth_Blue = srgb <0.125490196, 0.22745098, 0.337254902>;
#declare Lego_Earth_Green = srgb <0.152941176, 0.274509804, 0.17254902>;
#declare Lego_Earth_Orange = srgb <0.384313725, 0.278431373, 0.196078431>;
#declare Lego_Earth_Yellow = srgb <0.407843137, 0.360784314, 0.262745098>;
#declare Lego_Faded_Green = srgb <0.439215686, 0.584313725, 0.470588235>;
#declare Lego_Fire_Yellow = srgb <0.976470588, 0.839215686, 0.180392157>;
#declare Lego_Flame_Reddish_Orange = srgb <0.811764706, 0.376470588, 0.141176471>;
#declare Lego_Flame_Yellowish_Orange = srgb <0.909803922, 0.670588235, 0.176470588>;
#declare Lego_Gold = srgb <0.862745098, 0.737254902, 0.505882353>;
#declare Lego_Grey = srgb <0.631372549, 0.647058824, 0.635294118>;
#declare Lego_Gun_Metallic = srgb <0.458823529, 0.423529412, 0.384313725>;
#declare Lego_Lemon_Metalic = srgb <0.509803922, 0.541176471, 0.364705882>;
#declare Lego_Light_Blue = srgb <0.705882353, 0.823529412, 0.890196078>;
#declare Lego_Light_Bluish_Green = srgb <0.717647059, 0.843137255, 0.835294118>;
#declare Lego_Light_Bluish_Violet = srgb <0.756862745, 0.792156863, 0.870588235>;
#declare Lego_Light_Brick_Yellow = srgb <0.941176471, 0.835294118, 0.62745098>;
#declare Lego_Light_Green = srgb <0.760784314, 0.854901961, 0.721568627>;
#declare Lego_Light_Grey = srgb <0.780392157, 0.756862745, 0.717647059>;
#declare Lego_Light_Grey_Metallic = srgb <0.670588235, 0.678431373, 0.674509804>;
#declare Lego_Light_Lilac = srgb <0.654901961, 0.662745098, 0.807843137>;
#declare Lego_Light_Orange = srgb <0.917647059, 0.721568627, 0.568627451>;
#declare Lego_Light_Orange_Brown = srgb <0.796078431, 0.517647059, 0.258823529>;
#declare Lego_Light_Pink = srgb <0.862745098, 0.564705882, 0.584313725>;
#declare Lego_Light_Purple = srgb <0.894117647, 0.678431373, 0.784313725>;
#declare Lego_Light_Red = srgb <0.933333333, 0.768627451, 0.71372549>;
#declare Lego_Light_Reddish_Violet = srgb <0.909803922, 0.729411765, 0.780392157>;
#declare Lego_Light_Royal_Blue = srgb <0.623529412, 0.764705882, 0.91372549>;
#declare Lego_Light_Stone_Grey = srgb <0.898039216, 0.894117647, 0.870588235>;
#declare Lego_Light_Yellow = srgb <0.976470588, 0.91372549, 0.6>;
#declare Lego_Light_Yellowish_Green = srgb <0.850980392, 0.894117647, 0.654901961>;
#declare Lego_Light_Yellowish_Orange = srgb <0.952941176, 0.811764706, 0.607843137>;
#declare Lego_Lilac = srgb <0.419607843, 0.384313725, 0.607843137>;
#declare Lego_Medium_Blue = srgb <0.431372549, 0.6, 0.788235294>;
#declare Lego_Medium_Bluish_Green = srgb <0.333333333, 0.647058824, 0.68627451>;
#declare Lego_Medium_Bluish_Violet = srgb <0.407843137, 0.454901961, 0.674509804>;
#declare Lego_Medium_Green = srgb <0.631372549, 0.768627451, 0.545098039>;
#declare Lego_Medium_Lilac = srgb <0.203921569, 0.168627451, 0.458823529>;
#declare Lego_Medium_Orange = srgb <0.878431373, 0.596078431, 0.392156863>;
#declare Lego_Medium_Red = srgb <0.854901961, 0.525490196, 0.474509804>;
#declare Lego_Medium_Reddish_Violet = srgb <0.768627451, 0.439215686, 0.62745098>;
#declare Lego_Medium_Royal_Blue = srgb <0.423529412, 0.505882353, 0.717647059>;
#declare Lego_Medium_Stone_Grey = srgb <0.639215686, 0.635294118, 0.643137255>;
#declare Lego_Medium_Yellowish_Green = srgb <0.780392157, 0.823529412, 0.235294118>;
#declare Lego_Medium_Yellowish_Orange = srgb <0.905882353, 0.674509804, 0.345098039>;
#declare Lego_Neon_Green = srgb <0.847058824, 0.866666667, 0.337254902>;
#declare Lego_Neon_Orange = srgb <0.835294118, 0.450980392, 0.239215686>;
#declare Lego_Nougat = srgb <0.8, 0.556862745, 0.407843137>;
#declare Lego_Phosph._White = srgb <0.925490196, 0.909803922, 0.870588235>;
#declare Lego_Red_Flip_Flop = srgb <0.592156863, 0.411764706, 0.356862745>;
#declare Lego_Reddish_Brown = srgb <0.411764706, 0.250980392, 0.152941176>;
#declare Lego_Reddish_Lilac = srgb <0.588235294, 0.439215686, 0.623529412>;
#declare Lego_Royal_Blue = srgb <0.274509804, 0.403921569, 0.643137255>;
#declare Lego_Rust = srgb <0.560784314, 0.298039216, 0.164705882>;
#declare Lego_Sand_Blue = srgb <0.454901961, 0.525490196, 0.611764706>;
#declare Lego_Sand_Blue_Metallic = srgb <0.474509804, 0.533333333, 0.631372549>;
#declare Lego_Sand_Green = srgb <0.470588235, 0.564705882, 0.505882353>;
#declare Lego_Sand_Red = srgb <0.584313725, 0.474509804, 0.462745098>;
#declare Lego_Sand_Violet = srgb <0.529411765, 0.48627451, 0.564705882>;
#declare Lego_Sand_Violet_Metallic = srgb <0.584313725, 0.556862745, 0.639215686>;
#declare Lego_Sand_Yellow = srgb <0.584313725, 0.541176471, 0.450980392>;
#declare Lego_Sand_Yellow_Metallic = srgb <0.576470588, 0.529411765, 0.403921569>;
#declare Lego_Silver = srgb <0.611764706, 0.639215686, 0.658823529>;
#declare Lego_Silver_Flip_Flop = srgb <0.537254902, 0.529411765, 0.533333333>;
#declare Lego_Transparent = srgb <0.925490196, 0.925490196, 0.925490196>;
#declare Lego_Transparent_Blue = srgb <0.482352941, 0.71372549, 0.909803922>;
#declare Lego_Transparent_Bright_Bluish_Violet = srgb <0.647058824, 0.647058824, 0.796078431>;
#declare Lego_Transparent_Brown = srgb <0.749019608, 0.717647059, 0.694117647>;
#declare Lego_Transparent_Fluorescent_Blue = srgb <0.811764706, 0.88627451, 0.968627451>;
#declare Lego_Transparent_Fluorescent_Green = srgb <0.97254902, 0.945098039, 0.517647059>;
#declare Lego_Transparent_Fluorescent_Red = srgb <0.882352941, 0.643137255, 0.760784314>;
#declare Lego_Transparent_Fluorescent_Reddish_Orange = srgb <0.850980392, 0.521568627, 0.423529412>;
#declare Lego_Transparent_Fluorescent_Yellow = srgb <1, 0.964705882, 0.482352941>;
#declare Lego_Transparent_Green = srgb <0.517647059, 0.71372549, 0.552941176>;
#declare Lego_Transparent_Lg_Blue = srgb <0.756862745, 0.874509804, 0.941176471>;
#declare Lego_Transparent_Medium_Reddish_Violet = srgb <0.894117647, 0.678431373, 0.784313725>;
#declare Lego_Transparent_Red = srgb <0.803921569, 0.329411765, 0.294117647>;
#declare Lego_Transparent_Yellow = srgb <0.968627451, 0.945098039, 0.552941176>;
#declare Lego_Turquoise = srgb <0.474509804, 0.709803922, 0.709803922>;
#declare Lego_Warm_Yellowish_Orange = srgb <0.921568627, 0.721568627, 0.498039216>;
#declare Lego_White = srgb <0.949019608, 0.952941176, 0.949019608>;
#declare Lego_Yellow_Flip_Flop = srgb <0.705882353, 0.517647059, 0.333333333>;


#version farger_Inc_Temp;
#end
